# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: enums_clientserver.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18\x65nums_clientserver.proto*\xf7\x8d\x03\n\x04\x45Msg\x12\x11\n\rk_EMsgInvalid\x10\x00\x12\x0f\n\x0bk_EMsgMulti\x10\x01\x12\x19\n\x15k_EMsgProtobufWrapped\x10\x02\x12\x15\n\x11k_EMsgBaseGeneral\x10\x64\x12\x16\n\x12k_EMsgGenericReply\x10\x64\x12\x17\n\x13k_EMsgDestJobFailed\x10q\x12\x0f\n\x0bk_EMsgAlert\x10s\x12\x15\n\x11k_EMsgSCIDRequest\x10x\x12\x16\n\x12k_EMsgSCIDResponse\x10y\x12\x16\n\x12k_EMsgJobHeartbeat\x10{\x12\x14\n\x10k_EMsgHubConnect\x10|\x12\x13\n\x0fk_EMsgSubscribe\x10~\x12\x14\n\x10k_EMRouteMessage\x10\x7f\x12\x14\n\x0fk_EMsgWGRequest\x10\x82\x01\x12\x15\n\x10k_EMsgWGResponse\x10\x83\x01\x12\x14\n\x0fk_EMsgKeepAlive\x10\x84\x01\x12\x1b\n\x16k_EMsgWebAPIJobRequest\x10\x85\x01\x12\x1c\n\x17k_EMsgWebAPIJobResponse\x10\x86\x01\x12\x1d\n\x18k_EMsgClientSessionStart\x10\x87\x01\x12\x1b\n\x16k_EMsgClientSessionEnd\x10\x88\x01\x12\x1e\n\x19k_EMsgClientSessionUpdate\x10\x89\x01\x12\x1a\n\x15k_EMsgStatsDeprecated\x10\x8a\x01\x12\x0f\n\nk_EMsgPing\x10\x8b\x01\x12\x17\n\x12k_EMsgPingResponse\x10\x8c\x01\x12\x10\n\x0bk_EMsgStats\x10\x8d\x01\x12 \n\x1bk_EMsgRequestFullStatsBlock\x10\x8e\x01\x12\x1b\n\x16k_EMsgLoadDBOCacheItem\x10\x8f\x01\x12#\n\x1ek_EMsgLoadDBOCacheItemResponse\x10\x90\x01\x12\"\n\x1dk_EMsgInvalidateDBOCacheItems\x10\x91\x01\x12\x18\n\x13k_EMsgServiceMethod\x10\x92\x01\x12 \n\x1bk_EMsgServiceMethodResponse\x10\x93\x01\x12 \n\x1bk_EMsgClientPackageVersions\x10\x94\x01\x12\x1b\n\x16k_EMsgTimestampRequest\x10\x95\x01\x12\x1c\n\x17k_EMsgTimestampResponse\x10\x96\x01\x12&\n!k_EMsgServiceMethodCallFromClient\x10\x97\x01\x12$\n\x1fk_EMsgServiceMethodSendToClient\x10\x98\x01\x12\x14\n\x0fk_EMsgBaseShell\x10\xc8\x01\x12\x16\n\x11k_EMsgAssignSysID\x10\xc8\x01\x12\x0f\n\nk_EMsgExit\x10\xc9\x01\x12\x15\n\x10k_EMsgDirRequest\x10\xca\x01\x12\x16\n\x11k_EMsgDirResponse\x10\xcb\x01\x12\x15\n\x10k_EMsgZipRequest\x10\xcc\x01\x12\x16\n\x11k_EMsgZipResponse\x10\xcd\x01\x12\x1f\n\x1ak_EMsgUpdateRecordResponse\x10\xd7\x01\x12\"\n\x1dk_EMsgUpdateCreditCardRequest\x10\xdd\x01\x12 \n\x1bk_EMsgUpdateUserBanResponse\x10\xe1\x01\x12\x18\n\x13k_EMsgPrepareToExit\x10\xe2\x01\x12#\n\x1ek_EMsgContentDescriptionUpdate\x10\xe3\x01\x12\x1a\n\x15k_EMsgTestResetServer\x10\xe4\x01\x12\x1a\n\x15k_EMsgUniverseChanged\x10\xe5\x01\x12 \n\x1bk_EMsgShellConfigInfoUpdate\x10\xe6\x01\x12(\n#k_EMsgRequestWindowsEventLogEntries\x10\xe9\x01\x12(\n#k_EMsgProvideWindowsEventLogEntries\x10\xea\x01\x12\x1a\n\x15k_EMsgShellSearchLogs\x10\xeb\x01\x12\"\n\x1dk_EMsgShellSearchLogsResponse\x10\xec\x01\x12#\n\x1ek_EMsgShellCheckWindowsUpdates\x10\xed\x01\x12+\n&k_EMsgShellCheckWindowsUpdatesResponse\x10\xee\x01\x12\x1e\n\x19k_EMsgTestFlushDelayedSQL\x10\xf0\x01\x12&\n!k_EMsgTestFlushDelayedSQLResponse\x10\xf1\x01\x12*\n%k_EMsgEnsureExecuteScheduledTask_TEST\x10\xf2\x01\x12\x32\n-k_EMsgEnsureExecuteScheduledTaskResponse_TEST\x10\xf3\x01\x12.\n)k_EMsgUpdateScheduledTaskEnableState_TEST\x10\xf4\x01\x12\x36\n1k_EMsgUpdateScheduledTaskEnableStateResponse_TEST\x10\xf5\x01\x12(\n#k_EMsgContentDescriptionDeltaUpdate\x10\xf6\x01\x12)\n$k_EMsgGMShellAndServerAddressUpdates\x10\xf7\x01\x12\x11\n\x0ck_EMsgBaseGM\x10\xac\x02\x12\x14\n\x0fk_EMsgHeartbeat\x10\xac\x02\x12\x16\n\x11k_EMsgShellFailed\x10\xad\x02\x12\x15\n\x10k_EMsgExitShells\x10\xb3\x02\x12\x14\n\x0fk_EMsgExitShell\x10\xb4\x02\x12\x1c\n\x17k_EMsgGracefulExitShell\x10\xb5\x02\x12$\n\x1fk_EMsgLicenseProcessingComplete\x10\xbc\x02\x12\x16\n\x11k_EMsgSetTestFlag\x10\xbd\x02\x12\x1f\n\x1ak_EMsgQueuedEmailsComplete\x10\xbe\x02\x12\x14\n\x0fk_EMsgGMDRMSync\x10\xc0\x02\x12\x1f\n\x1ak_EMsgPhysicalBoxInventory\x10\xc1\x02\x12\x1b\n\x16k_EMsgUpdateConfigFile\x10\xc2\x02\x12\x15\n\x10k_EMsgTestInitDB\x10\xc3\x02\x12\x1d\n\x18k_EMsgGMWriteConfigToSQL\x10\xc4\x02\x12 \n\x1bk_EMsgGMLoadActivationCodes\x10\xc5\x02\x12\x18\n\x13k_EMsgGMQueueForFBS\x10\xc6\x02\x12$\n\x1fk_EMsgGMSchemaConversionResults\x10\xc7\x02\x12#\n\x1ek_EMsgGMWriteShellFailureToSQL\x10\xc9\x02\x12$\n\x1fk_EMsgGMGetServiceMethodRouting\x10\xcb\x02\x12,\n\'k_EMsgGMGetServiceMethodRoutingResponse\x10\xcc\x02\x12*\n%k_EMsgGMTestNextBuildSchemaConversion\x10\xce\x02\x12\x32\n-k_EMsgGMTestNextBuildSchemaConversionResponse\x10\xcf\x02\x12\x1d\n\x18k_EMsgExpectShellRestart\x10\xd0\x02\x12\x19\n\x14k_EMsgHotFixProgress\x10\xd1\x02\x12+\n&k_EMsgGMStatsForwardToAdminConnections\x10\xd2\x02\x12\x1f\n\x1ak_EMsgGMGetModifiedConVars\x10\xd3\x02\x12\'\n\"k_EMsgGMGetModifiedConVarsResponse\x10\xd4\x02\x12\x12\n\rk_EMsgBaseAIS\x10\x90\x03\x12\'\n\"k_EMsgAISRequestContentDescription\x10\x92\x03\x12$\n\x1fk_EMsgAISGetPackageChangeNumber\x10\x95\x03\x12,\n\'k_EMsgAISGetPackageChangeNumberResponse\x10\x96\x03\x12\x1a\n\x15k_EMsgAIGetAppGCFlags\x10\xa7\x03\x12\"\n\x1dk_EMsgAIGetAppGCFlagsResponse\x10\xa8\x03\x12\x17\n\x12k_EMsgAIGetAppList\x10\xa9\x03\x12\x1f\n\x1ak_EMsgAIGetAppListResponse\x10\xaa\x03\x12!\n\x1ck_EMsgAISGetCouponDefinition\x10\xad\x03\x12)\n$k_EMsgAISGetCouponDefinitionResponse\x10\xae\x03\x12\x31\n,k_EMsgAISUpdateSubordinateContentDescription\x10\xaf\x03\x12\x39\n4k_EMsgAISUpdateSubordinateContentDescriptionResponse\x10\xb0\x03\x12\x1a\n\x15k_EMsgAISTestEnableGC\x10\xb1\x03\x12\x11\n\x0ck_EMsgBaseAM\x10\xf4\x03\x12!\n\x1ck_EMsgAMUpdateUserBanRequest\x10\xf8\x03\x12\x17\n\x12k_EMsgAMAddLicense\x10\xf9\x03\x12\x1f\n\x1ak_EMsgAMSendSystemIMToUser\x10\xfc\x03\x12\x1a\n\x15k_EMsgAMExtendLicense\x10\xfd\x03\x12 \n\x1bk_EMsgAMAddMinutesToLicense\x10\xfe\x03\x12\x1a\n\x15k_EMsgAMCancelLicense\x10\xff\x03\x12\x19\n\x14k_EMsgAMInitPurchase\x10\x80\x04\x12\x1d\n\x18k_EMsgAMPurchaseResponse\x10\x81\x04\x12\x1d\n\x18k_EMsgAMGetLegacyGameKey\x10\x84\x04\x12%\n k_EMsgAMGetLegacyGameKeyResponse\x10\x85\x04\x12!\n\x1ck_EMsgAMFindHungTransactions\x10\x86\x04\x12%\n k_EMsgAMSetAccountTrustedRequest\x10\x87\x04\x12\x1b\n\x16k_EMsgAMCancelPurchase\x10\x8a\x04\x12\x19\n\x14k_EMsgAMNewChallenge\x10\x8b\x04\x12\x1f\n\x1ak_EMsgAMFixPendingPurchase\x10\x8d\x04\x12\'\n\"k_EMsgAMFixPendingPurchaseResponse\x10\x8e\x04\x12\x19\n\x14k_EMsgAMIsUserBanned\x10\x8f\x04\x12\x18\n\x13k_EMsgAMRegisterKey\x10\x90\x04\x12 \n\x1bk_EMsgAMLoadActivationCodes\x10\x91\x04\x12(\n#k_EMsgAMLoadActivationCodesResponse\x10\x92\x04\x12\x1e\n\x19k_EMsgAMLookupKeyResponse\x10\x93\x04\x12\x16\n\x11k_EMsgAMLookupKey\x10\x94\x04\x12\x18\n\x13k_EMsgAMChatCleanup\x10\x95\x04\x12\x18\n\x13k_EMsgAMClanCleanup\x10\x96\x04\x12\x1d\n\x18k_EMsgAMFixPendingRefund\x10\x97\x04\x12\x1e\n\x19k_EMsgAMReverseChargeback\x10\x98\x04\x12&\n!k_EMsgAMReverseChargebackResponse\x10\x99\x04\x12\x1c\n\x17k_EMsgAMClanCleanupList\x10\x9a\x04\x12\x1f\n\x1ak_EMsgAMSendCartRepurchase\x10\x9d\x04\x12\'\n\"k_EMsgAMSendCartRepurchaseResponse\x10\x9e\x04\x12\x1f\n\x1ak_EMsgAllowUserToPlayQuery\x10\xa6\x04\x12\"\n\x1dk_EMsgAllowUserToPlayResponse\x10\xa7\x04\x12\x17\n\x12k_EMsgAMVerfiyUser\x10\xa8\x04\x12\x1d\n\x18k_EMsgAMClientNotPlaying\x10\xa9\x04\x12$\n\x1fk_EMsgAMClientRequestFriendship\x10\xaa\x04\x12\x1f\n\x1ak_EMsgAMRelayPublishStatus\x10\xab\x04\x12!\n\x1ck_EMsgAMInitPurchaseResponse\x10\xb0\x04\x12#\n\x1ek_EMsgAMRevokePurchaseResponse\x10\xb1\x04\x12\x1f\n\x1ak_EMsgAMRefreshGuestPasses\x10\xb3\x04\x12\x1d\n\x18k_EMsgAMGrantGuestPasses\x10\xb6\x04\x12\x1c\n\x17k_EMsgAMClanDataUpdated\x10\xb7\x04\x12\x1a\n\x15k_EMsgAMReloadAccount\x10\xb8\x04\x12\x1f\n\x1ak_EMsgAMClientChatMsgRelay\x10\xb9\x04\x12\x16\n\x11k_EMsgAMChatMulti\x10\xba\x04\x12\"\n\x1dk_EMsgAMClientChatInviteRelay\x10\xbb\x04\x12\x17\n\x12k_EMsgAMChatInvite\x10\xbc\x04\x12 \n\x1bk_EMsgAMClientJoinChatRelay\x10\xbd\x04\x12&\n!k_EMsgAMClientChatMemberInfoRelay\x10\xbe\x04\x12\"\n\x1dk_EMsgAMPublishChatMemberInfo\x10\xbf\x04\x12%\n k_EMsgAMClientAcceptFriendInvite\x10\xc0\x04\x12\x16\n\x11k_EMsgAMChatEnter\x10\xc1\x04\x12+\n&k_EMsgAMClientPublishRemovalFromSource\x10\xc2\x04\x12\x1d\n\x18k_EMsgAMChatActionResult\x10\xc3\x04\x12\x19\n\x14k_EMsgAMFindAccounts\x10\xc4\x04\x12!\n\x1ck_EMsgAMFindAccountsResponse\x10\xc5\x04\x12\x1f\n\x1ak_EMsgAMIsAccountNameInUse\x10\xc6\x04\x12\'\n\"k_EMsgAMIsAccountNameInUseResponse\x10\xc7\x04\x12\x1c\n\x17k_EMsgAMSetAccountFlags\x10\xc8\x04\x12\x17\n\x12k_EMsgAMCreateClan\x10\xca\x04\x12\x1f\n\x1ak_EMsgAMCreateClanResponse\x10\xcb\x04\x12\x1b\n\x16k_EMsgAMGetClanDetails\x10\xcc\x04\x12#\n\x1ek_EMsgAMGetClanDetailsResponse\x10\xcd\x04\x12\x1b\n\x16k_EMsgAMSetPersonaName\x10\xce\x04\x12\x16\n\x11k_EMsgAMSetAvatar\x10\xcf\x04\x12\x1d\n\x18k_EMsgAMAuthenticateUser\x10\xd0\x04\x12%\n k_EMsgAMAuthenticateUserResponse\x10\xd1\x04\x12!\n\x1ck_EMsgAMP2PIntroducerMessage\x10\xd4\x04\x12\x1b\n\x16k_EMsgClientChatAction\x10\xd5\x04\x12\"\n\x1dk_EMsgAMClientChatActionRelay\x10\xd6\x04\x12\x11\n\x0ck_EMsgBaseVS\x10\xd8\x04\x12\x17\n\x12k_EMsgReqChallenge\x10\xd8\x04\x12\x16\n\x11k_EMsgVACResponse\x10\xd9\x04\x12\x1b\n\x16k_EMsgReqChallengeTest\x10\xda\x04\x12\x16\n\x11k_EMsgVSMarkCheat\x10\xdc\x04\x12\x15\n\x10k_EMsgVSAddCheat\x10\xdd\x04\x12\x1b\n\x16k_EMsgVSPurgeCodeModDB\x10\xde\x04\x12 \n\x1bk_EMsgVSGetChallengeResults\x10\xdf\x04\x12 \n\x1bk_EMsgVSChallengeResultText\x10\xe0\x04\x12\x1b\n\x16k_EMsgVSReportLingerer\x10\xe1\x04\x12$\n\x1fk_EMsgVSRequestManagedChallenge\x10\xe2\x04\x12\x1b\n\x16k_EMsgVSLoadDBFinished\x10\xe3\x04\x12\x13\n\x0ek_EMsgBaseDRMS\x10\xf1\x04\x12\x1e\n\x19k_EMsgDRMBuildBlobRequest\x10\xf4\x04\x12\x1f\n\x1ak_EMsgDRMBuildBlobResponse\x10\xf5\x04\x12 \n\x1bk_EMsgDRMResolveGuidRequest\x10\xf6\x04\x12!\n\x1ck_EMsgDRMResolveGuidResponse\x10\xf7\x04\x12\x1f\n\x1ak_EMsgDRMVariabilityReport\x10\xf9\x04\x12\'\n\"k_EMsgDRMVariabilityReportResponse\x10\xfa\x04\x12\x1d\n\x18k_EMsgDRMStabilityReport\x10\xfb\x04\x12%\n k_EMsgDRMStabilityReportResponse\x10\xfc\x04\x12\"\n\x1dk_EMsgDRMDetailsReportRequest\x10\xfd\x04\x12#\n\x1ek_EMsgDRMDetailsReportResponse\x10\xfe\x04\x12\x19\n\x14k_EMsgDRMProcessFile\x10\xff\x04\x12\x19\n\x14k_EMsgDRMAdminUpdate\x10\x80\x05\x12!\n\x1ck_EMsgDRMAdminUpdateResponse\x10\x81\x05\x12\x12\n\rk_EMsgDRMSync\x10\x82\x05\x12\x1a\n\x15k_EMsgDRMSyncResponse\x10\x83\x05\x12!\n\x1ck_EMsgDRMProcessFileResponse\x10\x84\x05\x12\x1c\n\x17k_EMsgDRMEmptyGuidCache\x10\x85\x05\x12$\n\x1fk_EMsgDRMEmptyGuidCacheResponse\x10\x86\x05\x12\x11\n\x0ck_EMsgBaseCS\x10\x8a\x05\x12\x15\n\x10k_EMsgBaseClient\x10\xbc\x05\x12!\n\x1ck_EMsgClientLogOn_Deprecated\x10\xbd\x05\x12%\n k_EMsgClientAnonLogOn_Deprecated\x10\xbe\x05\x12\x1a\n\x15k_EMsgClientHeartBeat\x10\xbf\x05\x12\x1c\n\x17k_EMsgClientVACResponse\x10\xc0\x05\x12%\n k_EMsgClientGamesPlayed_obsolete\x10\xc1\x05\x12\x17\n\x12k_EMsgClientLogOff\x10\xc2\x05\x12\"\n\x1dk_EMsgClientNoUDPConnectivity\x10\xc3\x05\x12 \n\x1bk_EMsgClientConnectionStats\x10\xc6\x05\x12\x1d\n\x18k_EMsgClientPingResponse\x10\xc8\x05\x12\x1d\n\x18k_EMsgClientRemoveFriend\x10\xca\x05\x12&\n!k_EMsgClientGamesPlayedNoDataBlob\x10\xcb\x05\x12\x1d\n\x18k_EMsgClientChangeStatus\x10\xcc\x05\x12\"\n\x1dk_EMsgClientVacStatusResponse\x10\xcd\x05\x12\x1a\n\x15k_EMsgClientFriendMsg\x10\xce\x05\x12%\n k_EMsgClientGameConnect_obsolete\x10\xcf\x05\x12&\n!k_EMsgClientGamesPlayed2_obsolete\x10\xd0\x05\x12#\n\x1ek_EMsgClientGameEnded_obsolete\x10\xd1\x05\x12\x19\n\x14k_EMsgClientSystemIM\x10\xd6\x05\x12\x1c\n\x17k_EMsgClientSystemIMAck\x10\xd7\x05\x12\x1c\n\x17k_EMsgClientGetLicenses\x10\xd8\x05\x12!\n\x1ck_EMsgClientGetLegacyGameKey\x10\xda\x05\x12.\n)k_EMsgClientContentServerLogOn_Deprecated\x10\xdb\x05\x12\x1b\n\x16k_EMsgClientAckVACBan2\x10\xdc\x05\x12$\n\x1fk_EMsgClientGetPurchaseReceipts\x10\xe0\x05\x12&\n!k_EMsgClientGamesPlayed3_obsolete\x10\xe2\x05\x12\x1d\n\x18k_EMsgClientAckGuestPass\x10\xe4\x05\x12 \n\x1bk_EMsgClientRedeemGuestPass\x10\xe5\x05\x12\x1c\n\x17k_EMsgClientGamesPlayed\x10\xe6\x05\x12\x1c\n\x17k_EMsgClientRegisterKey\x10\xe7\x05\x12!\n\x1ck_EMsgClientInviteUserToClan\x10\xe8\x05\x12&\n!k_EMsgClientAcknowledgeClanInvite\x10\xe9\x05\x12&\n!k_EMsgClientPurchaseWithMachineID\x10\xea\x05\x12\x1e\n\x19k_EMsgClientAppUsageEvent\x10\xeb\x05\x12\x1e\n\x19k_EMsgClientLogOnResponse\x10\xef\x05\x12!\n\x1ck_EMsgClientSetHeartbeatRate\x10\xf3\x05\x12&\n!k_EMsgClientNotLoggedOnDeprecated\x10\xf4\x05\x12\x1a\n\x15k_EMsgClientLoggedOff\x10\xf5\x05\x12\x14\n\x0fk_EMsgGSApprove\x10\xf6\x05\x12\x11\n\x0ck_EMsgGSDeny\x10\xf7\x05\x12\x11\n\x0ck_EMsgGSKick\x10\xf8\x05\x12!\n\x1ck_EMsgClientPurchaseResponse\x10\xfb\x05\x12\x15\n\x10k_EMsgClientPing\x10\xfc\x05\x12\x14\n\x0fk_EMsgClientNOP\x10\xfd\x05\x12\x1d\n\x18k_EMsgClientPersonaState\x10\xfe\x05\x12\x1c\n\x17k_EMsgClientFriendsList\x10\xff\x05\x12\x1c\n\x17k_EMsgClientAccountInfo\x10\x80\x06\x12\x1b\n\x16k_EMsgClientNewsUpdate\x10\x83\x06\x12 \n\x1bk_EMsgClientGameConnectDeny\x10\x85\x06\x12\x18\n\x13k_EMsgGSStatusReply\x10\x86\x06\x12\"\n\x1dk_EMsgClientGameConnectTokens\x10\x8b\x06\x12\x1c\n\x17k_EMsgClientLicenseList\x10\x8c\x06\x12\x1d\n\x18k_EMsgClientVACBanStatus\x10\x8e\x06\x12\x1b\n\x16k_EMsgClientEncryptPct\x10\x90\x06\x12)\n$k_EMsgClientGetLegacyGameKeyResponse\x10\x91\x06\x12\x1a\n\x15k_EMsgClientAddFriend\x10\x97\x06\x12\"\n\x1dk_EMsgClientAddFriendResponse\x10\x98\x06\x12%\n k_EMsgClientAckGuestPassResponse\x10\x9c\x06\x12(\n#k_EMsgClientRedeemGuestPassResponse\x10\x9d\x06\x12&\n!k_EMsgClientUpdateGuestPassesList\x10\x9e\x06\x12\x18\n\x13k_EMsgClientChatMsg\x10\x9f\x06\x12\x1b\n\x16k_EMsgClientChatInvite\x10\xa0\x06\x12\x19\n\x14k_EMsgClientJoinChat\x10\xa1\x06\x12\x1f\n\x1ak_EMsgClientChatMemberInfo\x10\xa2\x06\x12\x30\n+k_EMsgClientLogOnWithCredentials_Deprecated\x10\xa3\x06\x12\'\n\"k_EMsgClientPasswordChangeResponse\x10\xa5\x06\x12\x1a\n\x15k_EMsgClientChatEnter\x10\xa7\x06\x12(\n#k_EMsgClientFriendRemovedFromSource\x10\xa8\x06\x12\x1b\n\x16k_EMsgClientCreateChat\x10\xa9\x06\x12#\n\x1ek_EMsgClientCreateChatResponse\x10\xaa\x06\x12%\n k_EMsgClientP2PIntroducerMessage\x10\xad\x06\x12!\n\x1ck_EMsgClientChatActionResult\x10\xae\x06\x12\"\n\x1dk_EMsgClientRequestFriendData\x10\xaf\x06\x12\x1d\n\x18k_EMsgClientGetUserStats\x10\xb2\x06\x12%\n k_EMsgClientGetUserStatsResponse\x10\xb3\x06\x12\x1f\n\x1ak_EMsgClientStoreUserStats\x10\xb4\x06\x12\'\n\"k_EMsgClientStoreUserStatsResponse\x10\xb5\x06\x12\x1a\n\x15k_EMsgClientClanState\x10\xb6\x06\x12\x1e\n\x19k_EMsgClientServiceModule\x10\xbe\x06\x12\x1c\n\x17k_EMsgClientServiceCall\x10\xbf\x06\x12$\n\x1fk_EMsgClientServiceCallResponse\x10\xc0\x06\x12&\n!k_EMsgClientNatTraversalStatEvent\x10\xc7\x06\x12 \n\x1bk_EMsgClientSteamUsageEvent\x10\xca\x06\x12\x1e\n\x19k_EMsgClientCheckPassword\x10\xcd\x06\x12\x1e\n\x19k_EMsgClientResetPassword\x10\xce\x06\x12&\n!k_EMsgClientCheckPasswordResponse\x10\xd0\x06\x12&\n!k_EMsgClientResetPasswordResponse\x10\xd1\x06\x12\x1d\n\x18k_EMsgClientSessionToken\x10\xd2\x06\x12!\n\x1ck_EMsgClientDRMProblemReport\x10\xd3\x06\x12 \n\x1bk_EMsgClientSetIgnoreFriend\x10\xd7\x06\x12(\n#k_EMsgClientSetIgnoreFriendResponse\x10\xd8\x06\x12&\n!k_EMsgClientGetAppOwnershipTicket\x10\xd9\x06\x12.\n)k_EMsgClientGetAppOwnershipTicketResponse\x10\xda\x06\x12%\n k_EMsgClientGetLobbyListResponse\x10\xdc\x06\x12\x1b\n\x16k_EMsgClientServerList\x10\xf0\x06\x12\x1f\n\x1ak_EMsgClientDRMBlobRequest\x10\x80\x07\x12 \n\x1bk_EMsgClientDRMBlobResponse\x10\x81\x07\x12\x19\n\x14k_EMsgBaseGameServer\x10\x84\x07\x12\x1d\n\x18k_EMsgGSDisconnectNotice\x10\x85\x07\x12\x13\n\x0ek_EMsgGSStatus\x10\x87\x07\x12\x18\n\x13k_EMsgGSUserPlaying\x10\x89\x07\x12\x14\n\x0fk_EMsgGSStatus2\x10\x8a\x07\x12 \n\x1bk_EMsgGSStatusUpdate_Unused\x10\x8b\x07\x12\x17\n\x12k_EMsgGSServerType\x10\x8c\x07\x12\x17\n\x12k_EMsgGSPlayerList\x10\x8d\x07\x12%\n k_EMsgGSGetUserAchievementStatus\x10\x8e\x07\x12-\n(k_EMsgGSGetUserAchievementStatusResponse\x10\x8f\x07\x12\x19\n\x14k_EMsgGSGetPlayStats\x10\x96\x07\x12!\n\x1ck_EMsgGSGetPlayStatsResponse\x10\x97\x07\x12\x1f\n\x1ak_EMsgGSGetUserGroupStatus\x10\x98\x07\x12\x1f\n\x1ak_EMsgAMGetUserGroupStatus\x10\x99\x07\x12\'\n\"k_EMsgAMGetUserGroupStatusResponse\x10\x9a\x07\x12\'\n\"k_EMsgGSGetUserGroupStatusResponse\x10\x9b\x07\x12\x1a\n\x15k_EMsgGSGetReputation\x10\xa8\x07\x12\"\n\x1dk_EMsgGSGetReputationResponse\x10\xa9\x07\x12\x1e\n\x19k_EMsgGSAssociateWithClan\x10\xaa\x07\x12&\n!k_EMsgGSAssociateWithClanResponse\x10\xab\x07\x12*\n%k_EMsgGSComputeNewPlayerCompatibility\x10\xac\x07\x12\x32\n-k_EMsgGSComputeNewPlayerCompatibilityResponse\x10\xad\x07\x12\x14\n\x0fk_EMsgBaseAdmin\x10\xe8\x07\x12\x13\n\x0ek_EMsgAdminCmd\x10\xe8\x07\x12\x1b\n\x16k_EMsgAdminCmdResponse\x10\xec\x07\x12 \n\x1bk_EMsgAdminLogListenRequest\x10\xed\x07\x12\x18\n\x13k_EMsgAdminLogEvent\x10\xee\x07\x12\x17\n\x12k_EMsgUniverseData\x10\xf2\x07\x12\x14\n\x0fk_EMsgAdminSpew\x10\xfb\x07\x12\x1c\n\x17k_EMsgAdminConsoleTitle\x10\xfc\x07\x12\x16\n\x11k_EMsgAdminGCSpew\x10\xff\x07\x12\x19\n\x14k_EMsgAdminGCCommand\x10\x80\x08\x12 \n\x1bk_EMsgAdminGCGetCommandList\x10\x81\x08\x12(\n#k_EMsgAdminGCGetCommandListResponse\x10\x82\x08\x12\x1c\n\x17k_EMsgFBSConnectionData\x10\x83\x08\x12\x17\n\x12k_EMsgAdminMsgSpew\x10\x84\x08\x12\x12\n\rk_EMsgBaseFBS\x10\xcc\x08\x12\x18\n\x13k_EMsgFBSReqVersion\x10\xcc\x08\x12\x19\n\x14k_EMsgFBSVersionInfo\x10\xcd\x08\x12\x1a\n\x15k_EMsgFBSForceRefresh\x10\xce\x08\x12\x19\n\x14k_EMsgFBSForceBounce\x10\xcf\x08\x12\x1b\n\x16k_EMsgFBSDeployPackage\x10\xd0\x08\x12\x1c\n\x17k_EMsgFBSDeployResponse\x10\xd1\x08\x12 \n\x1bk_EMsgFBSUpdateBootstrapper\x10\xd2\x08\x12\x16\n\x11k_EMsgFBSSetState\x10\xd3\x08\x12\x1c\n\x17k_EMsgFBSApplyOSUpdates\x10\xd4\x08\x12\x1a\n\x15k_EMsgFBSRunCMDScript\x10\xd5\x08\x12\x17\n\x12k_EMsgFBSRebootBox\x10\xd6\x08\x12\x1f\n\x1ak_EMsgFBSSetBigBrotherMode\x10\xd7\x08\x12\x1c\n\x17k_EMsgFBSMinidumpServer\x10\xd8\x08\x12!\n\x1ck_EMsgFBSDeployHotFixPackage\x10\xda\x08\x12\"\n\x1dk_EMsgFBSDeployHotFixResponse\x10\xdb\x08\x12\x1c\n\x17k_EMsgFBSDownloadHotFix\x10\xdc\x08\x12$\n\x1fk_EMsgFBSDownloadHotFixResponse\x10\xdd\x08\x12$\n\x1fk_EMsgFBSUpdateTargetConfigFile\x10\xde\x08\x12\x1e\n\x19k_EMsgFBSApplyAccountCred\x10\xdf\x08\x12&\n!k_EMsgFBSApplyAccountCredResponse\x10\xe0\x08\x12\x1b\n\x16k_EMsgFBSSetShellCount\x10\xe1\x08\x12\x1c\n\x17k_EMsgFBSTerminateShell\x10\xe2\x08\x12\x1f\n\x1ak_EMsgFBSQueryGMForRequest\x10\xe3\x08\x12\x1d\n\x18k_EMsgFBSQueryGMResponse\x10\xe4\x08\x12\x1e\n\x19k_EMsgFBSTerminateZombies\x10\xe5\x08\x12\"\n\x1dk_EMsgFBSInfoFromBootstrapper\x10\xe6\x08\x12\x1f\n\x1ak_EMsgFBSRebootBoxResponse\x10\xe7\x08\x12(\n#k_EMsgFBSBootstrapperPackageRequest\x10\xe8\x08\x12)\n$k_EMsgFBSBootstrapperPackageResponse\x10\xe9\x08\x12)\n$k_EMsgFBSBootstrapperGetPackageChunk\x10\xea\x08\x12\x31\n,k_EMsgFBSBootstrapperGetPackageChunkResponse\x10\xeb\x08\x12\x31\n,k_EMsgFBSBootstrapperPackageTransferProgress\x10\xec\x08\x12!\n\x1ck_EMsgFBSRestartBootstrapper\x10\xed\x08\x12\x1e\n\x19k_EMsgFBSPauseFrozenDumps\x10\xee\x08\x12\x17\n\x12k_EMsgBaseFileXfer\x10\xb0\t\x12\x1a\n\x15k_EMsgFileXferRequest\x10\xb0\t\x12\x1b\n\x16k_EMsgFileXferResponse\x10\xb1\t\x12\x17\n\x12k_EMsgFileXferData\x10\xb2\t\x12\x16\n\x11k_EMsgFileXferEnd\x10\xb3\t\x12\x1a\n\x15k_EMsgFileXferDataAck\x10\xb4\t\x12\x1a\n\x15k_EMsgBaseChannelAuth\x10\x94\n\x12\x1f\n\x1ak_EMsgChannelAuthChallenge\x10\x94\n\x12\x1e\n\x19k_EMsgChannelAuthResponse\x10\x95\n\x12\x1c\n\x17k_EMsgChannelAuthResult\x10\x96\n\x12 \n\x1bk_EMsgChannelEncryptRequest\x10\x97\n\x12!\n\x1ck_EMsgChannelEncryptResponse\x10\x98\n\x12\x1f\n\x1ak_EMsgChannelEncryptResult\x10\x99\n\x12\x11\n\x0ck_EMsgBaseBS\x10\xf8\n\x12\x1a\n\x15k_EMsgBSPurchaseStart\x10\xf9\n\x12\x1d\n\x18k_EMsgBSPurchaseResponse\x10\xfa\n\x12 \n\x1bk_EMsgBSAuthenticateCCTrans\x10\xfb\n\x12(\n#k_EMsgBSAuthenticateCCTransResponse\x10\xfc\n\x12\x1b\n\x16k_EMsgBSSettleComplete\x10\xfe\n\x12\x1a\n\x15k_EMsgBSInitPayPalTxn\x10\x80\x0b\x12\"\n\x1dk_EMsgBSInitPayPalTxnResponse\x10\x81\x0b\x12\x1e\n\x19k_EMsgBSGetPayPalUserInfo\x10\x82\x0b\x12&\n!k_EMsgBSGetPayPalUserInfoResponse\x10\x83\x0b\x12\x1c\n\x17k_EMsgBSPaymentInstrBan\x10\x89\x0b\x12$\n\x1fk_EMsgBSPaymentInstrBanResponse\x10\x8a\x0b\x12\x1e\n\x19k_EMsgBSInitGCBankXferTxn\x10\x8d\x0b\x12&\n!k_EMsgBSInitGCBankXferTxnResponse\x10\x8e\x0b\x12\x18\n\x13k_EMsgBSCommitGCTxn\x10\x91\x0b\x12#\n\x1ek_EMsgBSQueryTransactionStatus\x10\x92\x0b\x12+\n&k_EMsgBSQueryTransactionStatusResponse\x10\x93\x0b\x12!\n\x1ck_EMsgBSQueryTxnExtendedInfo\x10\x99\x0b\x12)\n$k_EMsgBSQueryTxnExtendedInfoResponse\x10\x9a\x0b\x12\"\n\x1dk_EMsgBSUpdateConversionRates\x10\x9b\x0b\x12#\n\x1ek_EMsgBSPurchaseRunFraudChecks\x10\x9d\x0b\x12+\n&k_EMsgBSPurchaseRunFraudChecksResponse\x10\x9e\x0b\x12!\n\x1ck_EMsgBSQueryBankInformation\x10\xa0\x0b\x12)\n$k_EMsgBSQueryBankInformationResponse\x10\xa1\x0b\x12$\n\x1fk_EMsgBSValidateXsollaSignature\x10\xa5\x0b\x12,\n\'k_EMsgBSValidateXsollaSignatureResponse\x10\xa6\x0b\x12\x1e\n\x19k_EMsgBSQiwiWalletInvoice\x10\xa8\x0b\x12&\n!k_EMsgBSQiwiWalletInvoiceResponse\x10\xa9\x0b\x12\'\n\"k_EMsgBSUpdateInventoryFromProPack\x10\xaa\x0b\x12/\n*k_EMsgBSUpdateInventoryFromProPackResponse\x10\xab\x0b\x12 \n\x1bk_EMsgBSSendShippingRequest\x10\xac\x0b\x12(\n#k_EMsgBSSendShippingRequestResponse\x10\xad\x0b\x12\"\n\x1dk_EMsgBSGetProPackOrderStatus\x10\xae\x0b\x12*\n%k_EMsgBSGetProPackOrderStatusResponse\x10\xaf\x0b\x12\x1c\n\x17k_EMsgBSCheckJobRunning\x10\xb0\x0b\x12$\n\x1fk_EMsgBSCheckJobRunningResponse\x10\xb1\x0b\x12*\n%k_EMsgBSResetPackagePurchaseRateLimit\x10\xb2\x0b\x12\x32\n-k_EMsgBSResetPackagePurchaseRateLimitResponse\x10\xb3\x0b\x12\x1e\n\x19k_EMsgBSUpdatePaymentData\x10\xb4\x0b\x12&\n!k_EMsgBSUpdatePaymentDataResponse\x10\xb5\x0b\x12\x1e\n\x19k_EMsgBSGetBillingAddress\x10\xb6\x0b\x12&\n!k_EMsgBSGetBillingAddressResponse\x10\xb7\x0b\x12\x1e\n\x19k_EMsgBSGetCreditCardInfo\x10\xb8\x0b\x12&\n!k_EMsgBSGetCreditCardInfoResponse\x10\xb9\x0b\x12%\n k_EMsgBSRemoveExpiredPaymentData\x10\xbc\x0b\x12-\n(k_EMsgBSRemoveExpiredPaymentDataResponse\x10\xbd\x0b\x12!\n\x1ck_EMsgBSConvertToCurrentKeys\x10\xbe\x0b\x12)\n$k_EMsgBSConvertToCurrentKeysResponse\x10\xbf\x0b\x12\x19\n\x14k_EMsgBSInitPurchase\x10\xc0\x0b\x12!\n\x1ck_EMsgBSInitPurchaseResponse\x10\xc1\x0b\x12\x1d\n\x18k_EMsgBSCompletePurchase\x10\xc2\x0b\x12%\n k_EMsgBSCompletePurchaseResponse\x10\xc3\x0b\x12 \n\x1bk_EMsgBSPruneCardUsageStats\x10\xc4\x0b\x12(\n#k_EMsgBSPruneCardUsageStatsResponse\x10\xc5\x0b\x12!\n\x1ck_EMsgBSStoreBankInformation\x10\xc6\x0b\x12)\n$k_EMsgBSStoreBankInformationResponse\x10\xc7\x0b\x12\x1a\n\x15k_EMsgBSVerifyPOSAKey\x10\xc8\x0b\x12\"\n\x1dk_EMsgBSVerifyPOSAKeyResponse\x10\xc9\x0b\x12!\n\x1ck_EMsgBSReverseRedeemPOSAKey\x10\xca\x0b\x12)\n$k_EMsgBSReverseRedeemPOSAKeyResponse\x10\xcb\x0b\x12 \n\x1bk_EMsgBSQueryFindCreditCard\x10\xcc\x0b\x12(\n#k_EMsgBSQueryFindCreditCardResponse\x10\xcd\x0b\x12!\n\x1ck_EMsgBSStatusInquiryPOSAKey\x10\xce\x0b\x12)\n$k_EMsgBSStatusInquiryPOSAKeyResponse\x10\xcf\x0b\x12,\n\'k_EMsgBSBoaCompraConfirmProductDelivery\x10\xd6\x0b\x12\x34\n/k_EMsgBSBoaCompraConfirmProductDeliveryResponse\x10\xd7\x0b\x12!\n\x1ck_EMsgBSGenerateBoaCompraMD5\x10\xd8\x0b\x12)\n$k_EMsgBSGenerateBoaCompraMD5Response\x10\xd9\x0b\x12\x18\n\x13k_EMsgBSCommitWPTxn\x10\xda\x0b\x12\x1b\n\x16k_EMsgBSCommitAdyenTxn\x10\xdb\x0b\x12\x12\n\rk_EMsgBaseATS\x10\xdc\x0b\x12\x1d\n\x18k_EMsgATSStartStressTest\x10\xdd\x0b\x12\x1c\n\x17k_EMsgATSStopStressTest\x10\xde\x0b\x12\x1f\n\x1ak_EMsgATSRunFailServerTest\x10\xdf\x0b\x12\x1d\n\x18k_EMsgATSUFSPerfTestTask\x10\xe0\x0b\x12!\n\x1ck_EMsgATSUFSPerfTestResponse\x10\xe1\x0b\x12\x16\n\x11k_EMsgATSCycleTCM\x10\xe2\x0b\x12 \n\x1bk_EMsgATSInitDRMSStressTest\x10\xe3\x0b\x12\x16\n\x11k_EMsgATSCallTest\x10\xe4\x0b\x12\x1b\n\x16k_EMsgATSCallTestReply\x10\xe5\x0b\x12!\n\x1ck_EMsgATSStartExternalStress\x10\xe6\x0b\x12$\n\x1fk_EMsgATSExternalStressJobStart\x10\xe7\x0b\x12%\n k_EMsgATSExternalStressJobQueued\x10\xe8\x0b\x12&\n!k_EMsgATSExternalStressJobRunning\x10\xe9\x0b\x12&\n!k_EMsgATSExternalStressJobStopped\x10\xea\x0b\x12&\n!k_EMsgATSExternalStressJobStopAll\x10\xeb\x0b\x12(\n#k_EMsgATSExternalStressActionResult\x10\xec\x0b\x12\x15\n\x10k_EMsgATSStarted\x10\xed\x0b\x12\x1c\n\x17k_EMsgATSCSPerfTestTask\x10\xee\x0b\x12 \n\x1bk_EMsgATSCSPerfTestResponse\x10\xef\x0b\x12\x11\n\x0ck_EMsgBaseDP\x10\xc0\x0c\x12\x1f\n\x1ak_EMsgDPSetPublishingState\x10\xc1\x0c\x12\x1e\n\x19k_EMsgDPUniquePlayersStat\x10\xc3\x0c\x12\x17\n\x12k_EMsgDPCloudStats\x10\xcc\x0c\x12\x1b\n\x16k_EMsgDPGetPlayerCount\x10\xcf\x0c\x12#\n\x1ek_EMsgDPGetPlayerCountResponse\x10\xd0\x0c\x12$\n\x1fk_EMsgDPGameServersPlayersStats\x10\xd1\x0c\x12%\n k_EMsgClientDPCheckSpecialSurvey\x10\xd4\x0c\x12-\n(k_EMsgClientDPCheckSpecialSurveyResponse\x10\xd5\x0c\x12,\n\'k_EMsgClientDPSendSpecialSurveyResponse\x10\xd6\x0c\x12\x31\n,k_EMsgClientDPSendSpecialSurveyResponseReply\x10\xd7\x0c\x12 \n\x1bk_EMsgDPStoreSaleStatistics\x10\xd8\x0c\x12\x1d\n\x18k_EMsgDPPartnerMicroTxns\x10\xdc\x0c\x12%\n k_EMsgDPPartnerMicroTxnsResponse\x10\xdd\x0c\x12 \n\x1bk_EMsgDPVRUniquePlayersStat\x10\xdf\x0c\x12\x11\n\x0ck_EMsgBaseCM\x10\xa4\r\x12\x1a\n\x15k_EMsgCMSetAllowState\x10\xa5\r\x12\x1b\n\x16k_EMsgCMSpewAllowState\x10\xa6\r\x12\x1c\n\x17k_EMsgCMSessionRejected\x10\xa7\r\x12\x17\n\x12k_EMsgCMSetSecrets\x10\xa8\r\x12\x17\n\x12k_EMsgCMGetSecrets\x10\xa9\r\x12\"\n\x1dk_EMsgCMRemotePlayReplyPacket\x10\xaa\r\x12\x11\n\x0ck_EMsgBaseGC\x10\x98\x11\x12\x16\n\x11k_EMsgGCCmdRevive\x10\x9b\x11\x12\x14\n\x0fk_EMsgGCCmdDown\x10\x9e\x11\x12\x16\n\x11k_EMsgGCCmdDeploy\x10\x9f\x11\x12\x1e\n\x19k_EMsgGCCmdDeployResponse\x10\xa0\x11\x12\x16\n\x11k_EMsgGCCmdSwitch\x10\xa1\x11\x12\x1c\n\x17k_EMsgAMRefreshSessions\x10\xa2\x11\x12\x1f\n\x1ak_EMsgGCAchievementAwarded\x10\xa4\x11\x12\x16\n\x11k_EMsgGCCmdStatus\x10\xa8\x11\x12-\n(k_EMsgGCRegisterWebInterfaces_Deprecated\x10\xa9\x11\x12)\n$k_EMsgGCGetAccountDetails_DEPRECATED\x10\xaa\x11\x12\x1c\n\x17k_EMsgGCInterAppMessage\x10\xab\x11\x12\x1d\n\x18k_EMsgGCGetEmailTemplate\x10\xac\x11\x12%\n k_EMsgGCGetEmailTemplateResponse\x10\xad\x11\x12\x13\n\x0ek_EMsgGCHRelay\x10\xae\x11\x12\x1b\n\x16k_EMsgGCHRelayToClient\x10\xaf\x11\x12\x1b\n\x16k_EMsgGCHUpdateSession\x10\xb0\x11\x12\"\n\x1dk_EMsgGCHRequestUpdateSession\x10\xb1\x11\x12\x1b\n\x16k_EMsgGCHRequestStatus\x10\xb2\x11\x12#\n\x1ek_EMsgGCHRequestStatusResponse\x10\xb3\x11\x12$\n\x1fk_EMsgGCHAccountVacStatusChange\x10\xb4\x11\x12\x15\n\x10k_EMsgGCHSpawnGC\x10\xb5\x11\x12\x1d\n\x18k_EMsgGCHSpawnGCResponse\x10\xb6\x11\x12\x14\n\x0fk_EMsgGCHKillGC\x10\xb7\x11\x12\x1c\n\x17k_EMsgGCHKillGCResponse\x10\xb8\x11\x12)\n$k_EMsgGCHAccountTradeBanStatusChange\x10\xb9\x11\x12%\n k_EMsgGCHAccountLockStatusChange\x10\xba\x11\x12#\n\x1ek_EMsgGCHVacVerificationChange\x10\xbb\x11\x12&\n!k_EMsgGCHAccountPhoneNumberChange\x10\xbc\x11\x12$\n\x1fk_EMsgGCHAccountTwoFactorChange\x10\xbd\x11\x12\x1f\n\x1ak_EMsgGCHInviteUserToLobby\x10\xbe\x11\x12$\n\x1fk_EMsgGCHUpdateMultipleSessions\x10\xbf\x11\x12*\n%k_EMsgGCHMarkAppSessionsAuthoritative\x10\xc0\x11\x12/\n*k_EMsgGCHRecurringSubscriptionStatusChange\x10\xc1\x11\x12\x1f\n\x1ak_EMsgGCHAppCheersReceived\x10\xc2\x11\x12&\n!k_EMsgGCHAppCheersGetAllowedTypes\x10\xc3\x11\x12.\n)k_EMsgGCHAppCheersGetAllowedTypesResponse\x10\xc4\x11\x12%\n k_EMsgGCHRoutingRulesFromGCHtoGM\x10\xc5\x11\x12%\n k_EMsgGCHRoutingRulesToGCHfromGM\x10\xc6\x11\x12#\n\x1ek_EMsgUpdateCMMessageRateRules\x10\xc7\x11\x12\x12\n\rk_EMsgBaseP2P\x10\xc4\x13\x12\x1f\n\x1ak_EMsgP2PIntroducerMessage\x10\xc6\x13\x12\x11\n\x0ck_EMsgBaseSM\x10\xd4\x16\x12\x1c\n\x17k_EMsgSMExpensiveReport\x10\xd6\x16\x12\x19\n\x14k_EMsgSMHourlyReport\x10\xd7\x16\x12\x1d\n\x18k_EMsgSMPartitionRenames\x10\xd9\x16\x12\x19\n\x14k_EMsgSMMonitorSpace\x10\xda\x16\x12*\n%k_EMsgSMTestNextBuildSchemaConversion\x10\xdb\x16\x12\x32\n-k_EMsgSMTestNextBuildSchemaConversionResponse\x10\xdc\x16\x12\x13\n\x0ek_EMsgBaseTest\x10\xb8\x17\x12\x15\n\x10k_EMsgFailServer\x10\xb8\x17\x12\x1b\n\x16k_EMsgJobHeartbeatTest\x10\xb9\x17\x12#\n\x1ek_EMsgJobHeartbeatTestResponse\x10\xba\x17\x12\x17\n\x12k_EMsgBaseFTSRange\x10\x9c\x18\x12\x17\n\x12k_EMsgBaseCCSRange\x10\xce\x18\x12\'\n\"k_EMsgCCSDeleteAllCommentsByAuthor\x10\xd9\x18\x12/\n*k_EMsgCCSDeleteAllCommentsByAuthorResponse\x10\xda\x18\x12\x17\n\x12k_EMsgBaseLBSRange\x10\x80\x19\x12\x16\n\x11k_EMsgLBSSetScore\x10\x81\x19\x12\x1e\n\x19k_EMsgLBSSetScoreResponse\x10\x82\x19\x12\x1c\n\x17k_EMsgLBSFindOrCreateLB\x10\x83\x19\x12$\n\x1fk_EMsgLBSFindOrCreateLBResponse\x10\x84\x19\x12\x1a\n\x15k_EMsgLBSGetLBEntries\x10\x85\x19\x12\"\n\x1dk_EMsgLBSGetLBEntriesResponse\x10\x86\x19\x12\x17\n\x12k_EMsgLBSGetLBList\x10\x87\x19\x12\x1f\n\x1ak_EMsgLBSGetLBListResponse\x10\x88\x19\x12\x1a\n\x15k_EMsgLBSSetLBDetails\x10\x89\x19\x12\x16\n\x11k_EMsgLBSDeleteLB\x10\x8a\x19\x12\x1b\n\x16k_EMsgLBSDeleteLBEntry\x10\x8b\x19\x12\x15\n\x10k_EMsgLBSResetLB\x10\x8c\x19\x12\x1d\n\x18k_EMsgLBSResetLBResponse\x10\x8d\x19\x12\x1e\n\x19k_EMsgLBSDeleteLBResponse\x10\x8e\x19\x12\x12\n\rk_EMsgBaseOGS\x10\xc8\x1a\x12\x1a\n\x15k_EMsgOGSBeginSession\x10\xc9\x1a\x12\"\n\x1dk_EMsgOGSBeginSessionResponse\x10\xca\x1a\x12\x18\n\x13k_EMsgOGSEndSession\x10\xcb\x1a\x12 \n\x1bk_EMsgOGSEndSessionResponse\x10\xcc\x1a\x12 \n\x1bk_EMsgOGSWriteAppSessionRow\x10\xce\x1a\x12\x12\n\rk_EMsgBaseBRP\x10\x90\x1c\x12\x17\n\x12k_EMsgBaseAMRange2\x10\xa0\x1f\x12\x17\n\x12k_EMsgAMCreateChat\x10\xa1\x1f\x12\x1f\n\x1ak_EMsgAMCreateChatResponse\x10\xa2\x1f\x12#\n\x1ek_EMsgAMGetAccountEmailAddress\x10\xa6\x1f\x12+\n&k_EMsgAMGetAccountEmailAddressResponse\x10\xa7\x1f\x12\x1c\n\x17k_EMsgAMRequestClanData\x10\xa8\x1f\x12\x1b\n\x16k_EMsgAMRouteToClients\x10\xa9\x1f\x12\x16\n\x11k_EMsgAMLeaveClan\x10\xaa\x1f\x12\x1c\n\x17k_EMsgAMClanPermissions\x10\xab\x1f\x12$\n\x1fk_EMsgAMClanPermissionsResponse\x10\xac\x1f\x12\x30\n+k_EMsgAMCreateClanEventDummyForRateLimiting\x10\xad\x1f\x12\x30\n+k_EMsgAMUpdateClanEventDummyForRateLimiting\x10\xaf\x1f\x12&\n!k_EMsgAMSetClanPermissionSettings\x10\xb5\x1f\x12.\n)k_EMsgAMSetClanPermissionSettingsResponse\x10\xb6\x1f\x12&\n!k_EMsgAMGetClanPermissionSettings\x10\xb7\x1f\x12.\n)k_EMsgAMGetClanPermissionSettingsResponse\x10\xb8\x1f\x12 \n\x1bk_EMsgAMPublishChatRoomInfo\x10\xb9\x1f\x12\x1d\n\x18k_EMsgClientChatRoomInfo\x10\xba\x1f\x12\x1b\n\x16k_EMsgAMGetClanHistory\x10\xc7\x1f\x12#\n\x1ek_EMsgAMGetClanHistoryResponse\x10\xc8\x1f\x12\"\n\x1dk_EMsgAMGetClanPermissionBits\x10\xc9\x1f\x12*\n%k_EMsgAMGetClanPermissionBitsResponse\x10\xca\x1f\x12\"\n\x1dk_EMsgAMSetClanPermissionBits\x10\xcb\x1f\x12*\n%k_EMsgAMSetClanPermissionBitsResponse\x10\xcc\x1f\x12\x1f\n\x1ak_EMsgAMSessionInfoRequest\x10\xcd\x1f\x12 \n\x1bk_EMsgAMSessionInfoResponse\x10\xce\x1f\x12\x1c\n\x17k_EMsgAMValidateWGToken\x10\xcf\x1f\x12\x18\n\x13k_EMsgAMGetClanRank\x10\xd2\x1f\x12 \n\x1bk_EMsgAMGetClanRankResponse\x10\xd3\x1f\x12\x18\n\x13k_EMsgAMSetClanRank\x10\xd4\x1f\x12 \n\x1bk_EMsgAMSetClanRankResponse\x10\xd5\x1f\x12\x18\n\x13k_EMsgAMGetClanPOTW\x10\xd6\x1f\x12 \n\x1bk_EMsgAMGetClanPOTWResponse\x10\xd7\x1f\x12\x18\n\x13k_EMsgAMSetClanPOTW\x10\xd8\x1f\x12 \n\x1bk_EMsgAMSetClanPOTWResponse\x10\xd9\x1f\x12\x15\n\x10k_EMsgAMDumpUser\x10\xdb\x1f\x12\x1d\n\x18k_EMsgAMKickUserFromClan\x10\xdc\x1f\x12\x1d\n\x18k_EMsgAMAddFounderToClan\x10\xdd\x1f\x12$\n\x1fk_EMsgAMValidateWGTokenResponse\x10\xde\x1f\x12\x1e\n\x19k_EMsgAMSetAccountDetails\x10\xe0\x1f\x12\x1b\n\x16k_EMsgAMGetChatBanList\x10\xe1\x1f\x12#\n\x1ek_EMsgAMGetChatBanListResponse\x10\xe2\x1f\x12\x1a\n\x15k_EMsgAMUnBanFromChat\x10\xe3\x1f\x12\x1b\n\x16k_EMsgAMSetClanDetails\x10\xe4\x1f\x12\x1e\n\x19k_EMsgUGSGetUserGameStats\x10\xe9\x1f\x12&\n!k_EMsgUGSGetUserGameStatsResponse\x10\xea\x1f\x12 \n\x1bk_EMsgAMCheckClanMembership\x10\xeb\x1f\x12\x1b\n\x16k_EMsgAMGetClanMembers\x10\xec\x1f\x12#\n\x1ek_EMsgAMGetClanMembersResponse\x10\xed\x1f\x12#\n\x1ek_EMsgAMNotifyChatOfClanChange\x10\xef\x1f\x12\x1d\n\x18k_EMsgAMResubmitPurchase\x10\xf0\x1f\x12\x16\n\x11k_EMsgAMAddFriend\x10\xf1\x1f\x12\x1e\n\x19k_EMsgAMAddFriendResponse\x10\xf2\x1f\x12\x19\n\x14k_EMsgAMRemoveFriend\x10\xf3\x1f\x12\x15\n\x10k_EMsgAMDumpClan\x10\xf4\x1f\x12\x1c\n\x17k_EMsgAMChangeClanOwner\x10\xf5\x1f\x12\x1e\n\x19k_EMsgAMCancelEasyCollect\x10\xf6\x1f\x12&\n!k_EMsgAMCancelEasyCollectResponse\x10\xf7\x1f\x12\x1a\n\x15k_EMsgAMClansInCommon\x10\xfa\x1f\x12\"\n\x1dk_EMsgAMClansInCommonResponse\x10\xfb\x1f\x12\x1d\n\x18k_EMsgAMIsValidAccountID\x10\xfc\x1f\x12\x1c\n\x17k_EMsgAMWipeFriendsList\x10\xff\x1f\x12\x17\n\x12k_EMsgAMSetIgnored\x10\x80 \x12\'\n\"k_EMsgAMClansInCommonCountResponse\x10\x81 \x12\x18\n\x13k_EMsgAMFriendsList\x10\x82 \x12 \n\x1bk_EMsgAMFriendsListResponse\x10\x83 \x12\x1c\n\x17k_EMsgAMFriendsInCommon\x10\x84 \x12$\n\x1fk_EMsgAMFriendsInCommonResponse\x10\x85 \x12)\n$k_EMsgAMFriendsInCommonCountResponse\x10\x86 \x12\x1f\n\x1ak_EMsgAMClansInCommonCount\x10\x87 \x12\x1d\n\x18k_EMsgAMChallengeVerdict\x10\x88 \x12\"\n\x1dk_EMsgAMChallengeNotification\x10\x89 \x12\x17\n\x12k_EMsgAMFindGSByIP\x10\x8a \x12\x18\n\x13k_EMsgAMFoundGSByIP\x10\x8b \x12\x18\n\x13k_EMsgAMGiftRevoked\x10\x8c \x12\x19\n\x14k_EMsgAMUserClanList\x10\x8e \x12!\n\x1ck_EMsgAMUserClanListResponse\x10\x8f \x12\x1f\n\x1ak_EMsgAMGetAccountDetails2\x10\x90 \x12\'\n\"k_EMsgAMGetAccountDetailsResponse2\x10\x91 \x12(\n#k_EMsgAMSetCommunityProfileSettings\x10\x92 \x12\x30\n+k_EMsgAMSetCommunityProfileSettingsResponse\x10\x93 \x12%\n k_EMsgAMGetCommunityPrivacyState\x10\x94 \x12-\n(k_EMsgAMGetCommunityPrivacyStateResponse\x10\x95 \x12(\n#k_EMsgAMCheckClanInviteRateLimiting\x10\x96 \x12&\n!k_EMsgUGSGetUserAchievementStatus\x10\x97 \x12\x17\n\x12k_EMsgAMGetIgnored\x10\x98 \x12\x1f\n\x1ak_EMsgAMGetIgnoredResponse\x10\x99 \x12\x1f\n\x1ak_EMsgAMSetIgnoredResponse\x10\x9a \x12&\n!k_EMsgAMSetFriendRelationshipNone\x10\x9b \x12\"\n\x1dk_EMsgAMGetFriendRelationship\x10\x9c \x12*\n%k_EMsgAMGetFriendRelationshipResponse\x10\x9d \x12 \n\x1bk_EMsgAMServiceModulesCache\x10\x9e \x12\x1f\n\x1ak_EMsgAMServiceModulesCall\x10\x9f \x12\'\n\"k_EMsgAMServiceModulesCallResponse\x10\xa0 \x12!\n\x1ck_EMsgCommunityAddFriendNews\x10\xac \x12\x19\n\x14k_EMsgAMFindClanUser\x10\xaf \x12!\n\x1ck_EMsgAMFindClanUserResponse\x10\xb0 \x12\x18\n\x13k_EMsgAMBanFromChat\x10\xb1 \x12%\n k_EMsgAMGetUserNewsSubscriptions\x10\xb3 \x12-\n(k_EMsgAMGetUserNewsSubscriptionsResponse\x10\xb4 \x12%\n k_EMsgAMSetUserNewsSubscriptions\x10\xb5 \x12\x1d\n\x18k_EMsgAMSendQueuedEmails\x10\xb8 \x12\x1c\n\x17k_EMsgAMSetLicenseFlags\x10\xb9 \x12\x1d\n\x18k_EMsgAMGetAccountStatus\x10\xbe \x12%\n k_EMsgAMGetAccountStatusResponse\x10\xbf \x12\x1a\n\x15k_EMsgAMEditBanReason\x10\xc0 \x12(\n#k_EMsgAMCheckClanMembershipResponse\x10\xc1 \x12$\n\x1fk_EMsgAMProbeClanMembershipList\x10\xc2 \x12,\n\'k_EMsgAMProbeClanMembershipListResponse\x10\xc3 \x12.\n)k_EMsgUGSGetUserAchievementStatusResponse\x10\xc4 \x12\x1e\n\x19k_EMsgAMGetFriendsLobbies\x10\xc5 \x12&\n!k_EMsgAMGetFriendsLobbiesResponse\x10\xc6 \x12&\n!k_EMsgAMGetUserFriendNewsResponse\x10\xcc \x12%\n k_EMsgCommunityGetUserFriendNews\x10\xcd \x12%\n k_EMsgAMGetUserClansNewsResponse\x10\xce \x12\x1d\n\x18k_EMsgAMGetUserClansNews\x10\xcf \x12!\n\x1ck_EMsgAMGetPreviousCBAccount\x10\xd8 \x12)\n$k_EMsgAMGetPreviousCBAccountResponse\x10\xd9 \x12\"\n\x1dk_EMsgAMGetUserLicenseHistory\x10\xde \x12*\n%k_EMsgAMGetUserLicenseHistoryResponse\x10\xdf \x12\"\n\x1dk_EMsgAMSupportChangePassword\x10\xe2 \x12\x1f\n\x1ak_EMsgAMSupportChangeEmail\x10\xe3 \x12(\n#k_EMsgAMResetUserVerificationGSByIP\x10\xe5 \x12\x1e\n\x19k_EMsgAMUpdateGSPlayStats\x10\xe6 \x12#\n\x1ek_EMsgAMSupportEnableOrDisable\x10\xe7 \x12\x1e\n\x19k_EMsgAMGetPurchaseStatus\x10\xee \x12$\n\x1fk_EMsgAMSupportIsAccountEnabled\x10\xf1 \x12,\n\'k_EMsgAMSupportIsAccountEnabledResponse\x10\xf2 \x12\x1a\n\x15k_EMsgUGSGetUserStats\x10\xf3 \x12\x15\n\x10k_EMsgAMGSSearch\x10\xf5 \x12#\n\x1ek_EMsgChatServerRouteFriendMsg\x10\xfb \x12(\n#k_EMsgAMTicketAuthRequestOrResponse\x10\xfc \x12\x1b\n\x16k_EMsgAMAddFreeLicense\x10\x80!\x12\x1e\n\x19k_EMsgAMValidateEmailLink\x10\x87!\x12&\n!k_EMsgAMValidateEmailLinkResponse\x10\x88!\x12\x1c\n\x17k_EMsgUGSStoreUserStats\x10\x8c!\x12\x1d\n\x18k_EMsgAMDeleteStoredCard\x10\x91!\x12!\n\x1ck_EMsgAMRevokeLegacyGameKeys\x10\x92!\x12\x1d\n\x18k_EMsgAMGetWalletDetails\x10\x94!\x12%\n k_EMsgAMGetWalletDetailsResponse\x10\x95!\x12$\n\x1fk_EMsgAMDeleteStoredPaymentInfo\x10\x96!\x12$\n\x1fk_EMsgAMGetStoredPaymentSummary\x10\x97!\x12,\n\'k_EMsgAMGetStoredPaymentSummaryResponse\x10\x98!\x12$\n\x1fk_EMsgAMGetWalletConversionRate\x10\x99!\x12,\n\'k_EMsgAMGetWalletConversionRateResponse\x10\x9a!\x12\x1a\n\x15k_EMsgAMConvertWallet\x10\x9b!\x12\"\n\x1dk_EMsgAMConvertWalletResponse\x10\x9c!\x12\x1b\n\x16k_EMsgAMSetPreApproval\x10\x9f!\x12#\n\x1ek_EMsgAMSetPreApprovalResponse\x10\xa0!\x12\x19\n\x14k_EMsgAMCreateRefund\x10\xa2!\x12\x1d\n\x18k_EMsgAMCreateChargeback\x10\xa4!\x12\x1a\n\x15k_EMsgAMCreateDispute\x10\xa6!\x12\x19\n\x14k_EMsgAMClearDispute\x10\xa8!\x12&\n!k_EMsgAMCreateFinancialAdjustment\x10\xa9!\x12\x1f\n\x1ak_EMsgAMPlayerNicknameList\x10\xaa!\x12\'\n\"k_EMsgAMPlayerNicknameListResponse\x10\xab!\x12#\n\x1ek_EMsgAMGetUserCurrentGameInfo\x10\xad!\x12+\n&k_EMsgAMGetUserCurrentGameInfoResponse\x10\xae!\x12\x1c\n\x17k_EMsgAMGetGSPlayerList\x10\xaf!\x12$\n\x1fk_EMsgAMGetGSPlayerListResponse\x10\xb0!\x12\"\n\x1dk_EMsgAMGetSteamIDForMicroTxn\x10\xb6!\x12*\n%k_EMsgAMGetSteamIDForMicroTxnResponse\x10\xb7!\x12\x1d\n\x18k_EMsgAMSetPartnerMember\x10\xb8!\x12 \n\x1bk_EMsgAMRemovePublisherUser\x10\xb9!\x12\x1f\n\x1ak_EMsgAMGetUserLicenseList\x10\xba!\x12\'\n\"k_EMsgAMGetUserLicenseListResponse\x10\xbb!\x12\"\n\x1dk_EMsgAMReloadGameGroupPolicy\x10\xbc!\x12#\n\x1ek_EMsgAMAddFreeLicenseResponse\x10\xbd!\x12\x1c\n\x17k_EMsgAMVACStatusUpdate\x10\xbe!\x12\x1e\n\x19k_EMsgAMGetAccountDetails\x10\xbf!\x12&\n!k_EMsgAMGetAccountDetailsResponse\x10\xc0!\x12!\n\x1ck_EMsgAMGetPlayerLinkDetails\x10\xc1!\x12)\n$k_EMsgAMGetPlayerLinkDetailsResponse\x10\xc2!\x12)\n$k_EMsgAMGetAccountFlagsForWGSpoofing\x10\xc6!\x12\x31\n,k_EMsgAMGetAccountFlagsForWGSpoofingResponse\x10\xc7!\x12\x1c\n\x17k_EMsgAMGetClanOfficers\x10\xca!\x12$\n\x1fk_EMsgAMGetClanOfficersResponse\x10\xcb!\x12\x17\n\x12k_EMsgAMNameChange\x10\xcc!\x12\x1b\n\x16k_EMsgAMGetNameHistory\x10\xcd!\x12#\n\x1ek_EMsgAMGetNameHistoryResponse\x10\xce!\x12)\n$k_EMsgAMSupportRemoveAccountSecurity\x10\xd3!\x12*\n%k_EMsgAMIsAccountInCaptchaGracePeriod\x10\xd4!\x12\x32\n-k_EMsgAMIsAccountInCaptchaGracePeriodResponse\x10\xd5!\x12\x1d\n\x18k_EMsgAMAccountPS3Unlink\x10\xd6!\x12%\n k_EMsgAMAccountPS3UnlinkResponse\x10\xd7!\x12$\n\x1fk_EMsgUGSStoreUserStatsResponse\x10\xd8!\x12\x1e\n\x19k_EMsgAMGetAccountPSNInfo\x10\xd9!\x12&\n!k_EMsgAMGetAccountPSNInfoResponse\x10\xda!\x12$\n\x1fk_EMsgAMAuthenticatedPlayerList\x10\xdb!\x12\x19\n\x14k_EMsgAMGetUserGifts\x10\xdc!\x12!\n\x1ck_EMsgAMGetUserGiftsResponse\x10\xdd!\x12 \n\x1bk_EMsgAMTransferLockedGifts\x10\xe0!\x12(\n#k_EMsgAMTransferLockedGiftsResponse\x10\xe1!\x12%\n k_EMsgAMPlayerHostedOnGameServer\x10\xe2!\x12\x1e\n\x19k_EMsgAMGetAccountBanInfo\x10\xe3!\x12&\n!k_EMsgAMGetAccountBanInfoResponse\x10\xe4!\x12!\n\x1ck_EMsgAMRecordBanEnforcement\x10\xe5!\x12!\n\x1ck_EMsgAMRollbackGiftTransfer\x10\xe6!\x12)\n$k_EMsgAMRollbackGiftTransferResponse\x10\xe7!\x12%\n k_EMsgAMHandlePendingTransaction\x10\xe8!\x12\x1f\n\x1ak_EMsgAMRequestClanDetails\x10\xe9!\x12(\n#k_EMsgAMDeleteStoredPaypalAgreement\x10\xea!\x12\x1d\n\x18k_EMsgAMGameServerUpdate\x10\xeb!\x12\x1d\n\x18k_EMsgAMGameServerRemove\x10\xec!\x12 \n\x1bk_EMsgAMGetPaypalAgreements\x10\xed!\x12(\n#k_EMsgAMGetPaypalAgreementsResponse\x10\xee!\x12/\n*k_EMsgAMGameServerPlayerCompatibilityCheck\x10\xef!\x12\x37\n2k_EMsgAMGameServerPlayerCompatibilityCheckResponse\x10\xf0!\x12\x19\n\x14k_EMsgAMRenewLicense\x10\xf1!\x12\'\n\"k_EMsgAMGetAccountCommunityBanInfo\x10\xf2!\x12/\n*k_EMsgAMGetAccountCommunityBanInfoResponse\x10\xf3!\x12,\n\'k_EMsgAMGameServerAccountChangePassword\x10\xf4!\x12+\n&k_EMsgAMGameServerAccountDeleteAccount\x10\xf5!\x12\x1b\n\x16k_EMsgAMRenewAgreement\x10\xf6!\x12\x1a\n\x15k_EMsgAMXsollaPayment\x10\xf8!\x12\"\n\x1dk_EMsgAMXsollaPaymentResponse\x10\xf9!\x12\"\n\x1dk_EMsgAMAcctAllowedToPurchase\x10\xfa!\x12*\n%k_EMsgAMAcctAllowedToPurchaseResponse\x10\xfb!\x12\x1d\n\x18k_EMsgAMSwapKioskDeposit\x10\xfc!\x12%\n k_EMsgAMSwapKioskDepositResponse\x10\xfd!\x12\x1f\n\x1ak_EMsgAMSetUserGiftUnowned\x10\xfe!\x12\'\n\"k_EMsgAMSetUserGiftUnownedResponse\x10\xff!\x12!\n\x1ck_EMsgAMClaimUnownedUserGift\x10\x80\"\x12)\n$k_EMsgAMClaimUnownedUserGiftResponse\x10\x81\"\x12\x18\n\x13k_EMsgAMSetClanName\x10\x82\"\x12 \n\x1bk_EMsgAMSetClanNameResponse\x10\x83\"\x12\x18\n\x13k_EMsgAMGrantCoupon\x10\x84\"\x12 \n\x1bk_EMsgAMGrantCouponResponse\x10\x85\"\x12-\n(k_EMsgAMIsPackageRestrictedInUserCountry\x10\x86\"\x12\x35\n0k_EMsgAMIsPackageRestrictedInUserCountryResponse\x10\x87\"\x12-\n(k_EMsgAMHandlePendingTransactionResponse\x10\x88\"\x12\x1e\n\x19k_EMsgAMGrantGuestPasses2\x10\x89\"\x12&\n!k_EMsgAMGrantGuestPasses2Response\x10\x8a\"\x12 \n\x1bk_EMsgAMGetPlayerBanDetails\x10\x8d\"\x12(\n#k_EMsgAMGetPlayerBanDetailsResponse\x10\x8e\"\x12\x1d\n\x18k_EMsgAMFinalizePurchase\x10\x8f\"\x12%\n k_EMsgAMFinalizePurchaseResponse\x10\x90\"\x12\"\n\x1dk_EMsgAMPersonaChangeResponse\x10\x94\"\x12+\n&k_EMsgAMGetClanDetailsForForumCreation\x10\x95\"\x12\x33\n.k_EMsgAMGetClanDetailsForForumCreationResponse\x10\x96\"\x12(\n#k_EMsgAMGetPendingNotificationCount\x10\x97\"\x12\x30\n+k_EMsgAMGetPendingNotificationCountResponse\x10\x98\"\x12 \n\x1bk_EMsgAMPasswordHashUpgrade\x10\x99\"\x12\x1d\n\x18k_EMsgAMBoaCompraPayment\x10\x9c\"\x12%\n k_EMsgAMBoaCompraPaymentResponse\x10\x9d\"\x12%\n k_EMsgAMCompleteExternalPurchase\x10\x9f\"\x12-\n(k_EMsgAMCompleteExternalPurchaseResponse\x10\xa0\"\x12)\n$k_EMsgAMResolveNegativeWalletCredits\x10\xa1\"\x12\x31\n,k_EMsgAMResolveNegativeWalletCreditsResponse\x10\xa2\"\x12&\n!k_EMsgAMPlayerGetClanBasicDetails\x10\xa5\"\x12.\n)k_EMsgAMPlayerGetClanBasicDetailsResponse\x10\xa6\"\x12\x17\n\x12k_EMsgAMMOLPayment\x10\xa7\"\x12\x1f\n\x1ak_EMsgAMMOLPaymentResponse\x10\xa8\"\x12\x1b\n\x16k_EMsgGetUserIPCountry\x10\xa9\"\x12#\n\x1ek_EMsgGetUserIPCountryResponse\x10\xaa\"\x12+\n&k_EMsgNotificationOfSuspiciousActivity\x10\xab\"\x12\x1a\n\x15k_EMsgAMDegicaPayment\x10\xac\"\x12\"\n\x1dk_EMsgAMDegicaPaymentResponse\x10\xad\"\x12\x19\n\x14k_EMsgAMEClubPayment\x10\xae\"\x12!\n\x1ck_EMsgAMEClubPaymentResponse\x10\xaf\"\x12%\n k_EMsgAMPayPalPaymentsHubPayment\x10\xb0\"\x12-\n(k_EMsgAMPayPalPaymentsHubPaymentResponse\x10\xb1\"\x12\x31\n,k_EMsgAMTwoFactorRecoverAuthenticatorRequest\x10\xb2\"\x12\x32\n-k_EMsgAMTwoFactorRecoverAuthenticatorResponse\x10\xb3\"\x12\x1d\n\x18k_EMsgAMSmart2PayPayment\x10\xb4\"\x12%\n k_EMsgAMSmart2PayPaymentResponse\x10\xb5\"\x12\x37\n2k_EMsgAMValidatePasswordResetCodeAndSendSmsRequest\x10\xb6\"\x12\x38\n3k_EMsgAMValidatePasswordResetCodeAndSendSmsResponse\x10\xb7\"\x12*\n%k_EMsgAMGetAccountResetDetailsRequest\x10\xb8\"\x12+\n&k_EMsgAMGetAccountResetDetailsResponse\x10\xb9\"\x12\x1a\n\x15k_EMsgAMBitPayPayment\x10\xba\"\x12\"\n\x1dk_EMsgAMBitPayPaymentResponse\x10\xbb\"\x12\"\n\x1dk_EMsgAMSendAccountInfoUpdate\x10\xbc\"\x12\x1e\n\x19k_EMsgAMSendScheduledGift\x10\xbd\"\x12\x1a\n\x15k_EMsgAMNodwinPayment\x10\xbe\"\x12\"\n\x1dk_EMsgAMNodwinPaymentResponse\x10\xbf\"\x12 \n\x1bk_EMsgAMResolveWalletRevoke\x10\xc0\"\x12\'\n\"k_EMsgAMResolveWalletReverseRevoke\x10\xc1\"\x12\x1a\n\x15k_EMsgAMFundedPayment\x10\xc2\"\x12\"\n\x1dk_EMsgAMFundedPaymentResponse\x10\xc3\"\x12.\n)k_EMsgAMRequestPersonaUpdateForChatServer\x10\xc4\"\x12 \n\x1bk_EMsgAMPerfectWorldPayment\x10\xc5\"\x12(\n#k_EMsgAMPerfectWorldPaymentResponse\x10\xc6\"\x12\x1c\n\x17k_EMsgAMECommPayPayment\x10\xc7\"\x12$\n\x1fk_EMsgAMECommPayPaymentResponse\x10\xc8\"\x12\x1e\n\x19k_EMsgAMSetRemoteClientID\x10\xc9\"\x12\x16\n\x11k_EMsgBasePSRange\x10\x88\'\x12 \n\x1bk_EMsgPSIsValidShoppingCart\x10\x8b\'\x12(\n#k_EMsgPSIsValidShoppingCartResponse\x10\x8c\'\x12$\n\x1fk_EMsgPSGetShoppingCartContents\x10\x91\'\x12,\n\'k_EMsgPSGetShoppingCartContentsResponse\x10\x92\'\x12*\n%k_EMsgPSAddWalletCreditToShoppingCart\x10\x93\'\x12\x32\n-k_EMsgPSAddWalletCreditToShoppingCartResponse\x10\x94\'\x12#\n\x1ek_EMsgPSGetAccountCartContents\x10\x95\'\x12+\n&k_EMsgPSGetAccountCartContentsResponse\x10\x96\'\x12\x17\n\x12k_EMsgBaseUFSRange\x10\xd0(\x12!\n\x1ck_EMsgUFSReloadPartitionInfo\x10\xdf(\x12\x1d\n\x18k_EMsgUFSSynchronizeFile\x10\xe1(\x12%\n k_EMsgUFSSynchronizeFileResponse\x10\xe2(\x12!\n\x1ck_EMsgClientUFSGetUGCDetails\x10\xea(\x12)\n$k_EMsgClientUFSGetUGCDetailsResponse\x10\xeb(\x12\x1d\n\x18k_EMsgUFSUpdateFileFlags\x10\xec(\x12%\n k_EMsgUFSUpdateFileFlagsResponse\x10\xed(\x12%\n k_EMsgClientUFSGetSingleFileInfo\x10\xee(\x12-\n(k_EMsgClientUFSGetSingleFileInfoResponse\x10\xef(\x12\x1d\n\x18k_EMsgClientUFSShareFile\x10\xf0(\x12%\n k_EMsgClientUFSShareFileResponse\x10\xf1(\x12\x1b\n\x16k_EMsgUFSReloadAccount\x10\xf2(\x12#\n\x1ek_EMsgUFSReloadAccountResponse\x10\xf3(\x12!\n\x1ck_EMsgUFSUpdateRecordBatched\x10\xf4(\x12)\n$k_EMsgUFSUpdateRecordBatchedResponse\x10\xf5(\x12\x19\n\x14k_EMsgUFSMigrateFile\x10\xf6(\x12!\n\x1ck_EMsgUFSMigrateFileResponse\x10\xf7(\x12\x18\n\x13k_EMsgUFSGetUGCURLs\x10\xf8(\x12 \n\x1bk_EMsgUFSGetUGCURLsResponse\x10\xf9(\x12)\n$k_EMsgUFSHttpUploadFileFinishRequest\x10\xfa(\x12*\n%k_EMsgUFSHttpUploadFileFinishResponse\x10\xfb(\x12\"\n\x1dk_EMsgUFSDownloadStartRequest\x10\xfc(\x12#\n\x1ek_EMsgUFSDownloadStartResponse\x10\xfd(\x12\"\n\x1dk_EMsgUFSDownloadChunkRequest\x10\xfe(\x12#\n\x1ek_EMsgUFSDownloadChunkResponse\x10\xff(\x12#\n\x1ek_EMsgUFSDownloadFinishRequest\x10\x80)\x12$\n\x1fk_EMsgUFSDownloadFinishResponse\x10\x81)\x12\x1b\n\x16k_EMsgUFSFlushURLCache\x10\x82)\x12\x1e\n\x19k_EMsgUFSMigrateFileAppID\x10\x85)\x12&\n!k_EMsgUFSMigrateFileAppIDResponse\x10\x86)\x12\x16\n\x11k_EMsgBaseClient2\x10\x98*\x12.\n)k_EMsgClientRequestForgottenPasswordEmail\x10\x99*\x12\x36\n1k_EMsgClientRequestForgottenPasswordEmailResponse\x10\x9a*\x12&\n!k_EMsgClientCreateAccountResponse\x10\x9b*\x12\'\n\"k_EMsgClientResetForgottenPassword\x10\x9c*\x12/\n*k_EMsgClientResetForgottenPasswordResponse\x10\x9d*\x12/\n*k_EMsgClientInformOfResetForgottenPassword\x10\x9f*\x12\x37\n2k_EMsgClientInformOfResetForgottenPasswordResponse\x10\xa0*\x12)\n$k_EMsgClientAnonUserLogOn_Deprecated\x10\xa1*\x12(\n#k_EMsgClientGamesPlayedWithDataBlob\x10\xa2*\x12#\n\x1ek_EMsgClientUpdateUserGameInfo\x10\xa3*\x12\x1f\n\x1ak_EMsgClientFileToDownload\x10\xa4*\x12\'\n\"k_EMsgClientFileToDownloadResponse\x10\xa5*\x12\x1c\n\x17k_EMsgClientLBSSetScore\x10\xa6*\x12$\n\x1fk_EMsgClientLBSSetScoreResponse\x10\xa7*\x12\"\n\x1dk_EMsgClientLBSFindOrCreateLB\x10\xa8*\x12*\n%k_EMsgClientLBSFindOrCreateLBResponse\x10\xa9*\x12 \n\x1bk_EMsgClientLBSGetLBEntries\x10\xaa*\x12(\n#k_EMsgClientLBSGetLBEntriesResponse\x10\xab*\x12\x1d\n\x18k_EMsgClientChatDeclined\x10\xb2*\x12\"\n\x1dk_EMsgClientFriendMsgIncoming\x10\xb3*\x12$\n\x1fk_EMsgClientAuthList_Deprecated\x10\xb4*\x12#\n\x1ek_EMsgClientTicketAuthComplete\x10\xb5*\x12!\n\x1ck_EMsgClientIsLimitedAccount\x10\xb6*\x12 \n\x1bk_EMsgClientRequestAuthList\x10\xb7*\x12\x19\n\x14k_EMsgClientAuthList\x10\xb8*\x12 \n\x1bk_EMsgClientStat_Deprecated\x10\xb9*\x12\"\n\x1dk_EMsgClientP2PConnectionInfo\x10\xba*\x12&\n!k_EMsgClientP2PConnectionFailInfo\x10\xbb*\x12&\n!k_EMsgClientGetDepotDecryptionKey\x10\xbe*\x12.\n)k_EMsgClientGetDepotDecryptionKeyResponse\x10\xbf*\x12\"\n\x1dk_EMsgClientEnableTestLicense\x10\xc3*\x12*\n%k_EMsgClientEnableTestLicenseResponse\x10\xc4*\x12#\n\x1ek_EMsgClientDisableTestLicense\x10\xc5*\x12+\n&k_EMsgClientDisableTestLicenseResponse\x10\xc6*\x12%\n k_EMsgClientCheckAppBetaPassword\x10\xca*\x12-\n(k_EMsgClientCheckAppBetaPasswordResponse\x10\xcb*\x12\x15\n\x10k_EMsgClientToGC\x10\xcc*\x12\x17\n\x12k_EMsgClientFromGC\x10\xcd*\x12\x1e\n\x19k_EMsgClientEmailAddrInfo\x10\xd0*\x12 \n\x1bk_EMsgClientPasswordChange3\x10\xd1*\x12\x1d\n\x18k_EMsgClientEmailChange3\x10\xd2*\x12\"\n\x1dk_EMsgClientPersonalQAChange3\x10\xd3*\x12(\n#k_EMsgClientResetForgottenPassword3\x10\xd4*\x12/\n*k_EMsgClientRequestForgottenPasswordEmail3\x10\xd5*\x12\x1c\n\x17k_EMsgClientNewLoginKey\x10\xd7*\x12/\n*k_EMsgClientNewLoginKeyAccepted_Deprecated\x10\xd8*\x12)\n$k_EMsgClientLogOnWithHash_Deprecated\x10\xd9*\x12 \n\x1bk_EMsgClientStoreUserStats2\x10\xda*\x12\x1d\n\x18k_EMsgClientStatsUpdated\x10\xdb*\x12\x30\n+k_EMsgClientRequestedClientStats_Deprecated\x10\xe8*\x12&\n!k_EMsgClientStat2Int32_Deprecated\x10\xe9*\x12!\n\x1ck_EMsgClientStat2_Deprecated\x10\xea*\x12#\n\x1ek_EMsgClientDRMDownloadRequest\x10\xed*\x12$\n\x1fk_EMsgClientDRMDownloadResponse\x10\xee*\x12\x1f\n\x1ak_EMsgClientDRMFinalResult\x10\xef*\x12&\n!k_EMsgClientGetFriendsWhoPlayGame\x10\xf0*\x12.\n)k_EMsgClientGetFriendsWhoPlayGameResponse\x10\xf1*\x12 \n\x1bk_EMsgClientOGSBeginSession\x10\xf2*\x12(\n#k_EMsgClientOGSBeginSessionResponse\x10\xf3*\x12\x1e\n\x19k_EMsgClientOGSEndSession\x10\xf4*\x12&\n!k_EMsgClientOGSEndSessionResponse\x10\xf5*\x12\x1c\n\x17k_EMsgClientOGSWriteRow\x10\xf6*\x12#\n\x1ek_EMsgClientGetPeerContentInfo\x10\xf7*\x12+\n&k_EMsgClientGetPeerContentInfoResponse\x10\xf8*\x12\'\n\"k_EMsgClientStartPeerContentServer\x10\xf9*\x12/\n*k_EMsgClientStartPeerContentServerResponse\x10\xfa*\x12\"\n\x1dk_EMsgClientServerUnavailable\x10\xfc*\x12!\n\x1ck_EMsgClientServersAvailable\x10\xfd*\x12)\n$k_EMsgClientRegisterAuthTicketWithCM\x10\xfe*\x12\x1c\n\x17k_EMsgClientGCMsgFailed\x10\xff*\x12$\n\x1fk_EMsgClientMicroTxnAuthRequest\x10\x80+\x12\"\n\x1dk_EMsgClientMicroTxnAuthorize\x10\x81+\x12*\n%k_EMsgClientMicroTxnAuthorizeResponse\x10\x82+\x12 \n\x1bk_EMsgClientGetMicroTxnInfo\x10\x84+\x12(\n#k_EMsgClientGetMicroTxnInfoResponse\x10\x85+\x12%\n k_EMsgClientDeregisterWithServer\x10\x87+\x12\'\n\"k_EMsgClientSubscribeToPersonaFeed\x10\x88+\x12\x16\n\x11k_EMsgClientLogon\x10\x8a+\x12!\n\x1ck_EMsgClientGetClientDetails\x10\x8b+\x12)\n$k_EMsgClientGetClientDetailsResponse\x10\x8c+\x12+\n&k_EMsgClientReportOverlayDetourFailure\x10\x8d+\x12!\n\x1ck_EMsgClientGetClientAppList\x10\x8e+\x12)\n$k_EMsgClientGetClientAppListResponse\x10\x8f+\x12!\n\x1ck_EMsgClientInstallClientApp\x10\x90+\x12)\n$k_EMsgClientInstallClientAppResponse\x10\x91+\x12#\n\x1ek_EMsgClientUninstallClientApp\x10\x92+\x12+\n&k_EMsgClientUninstallClientAppResponse\x10\x93+\x12(\n#k_EMsgClientSetClientAppUpdateState\x10\x94+\x12\x30\n+k_EMsgClientSetClientAppUpdateStateResponse\x10\x95+\x12*\n%k_EMsgClientRequestEncryptedAppTicket\x10\x96+\x12\x32\n-k_EMsgClientRequestEncryptedAppTicketResponse\x10\x97+\x12!\n\x1ck_EMsgClientWalletInfoUpdate\x10\x98+\x12\x1a\n\x15k_EMsgClientLBSSetUGC\x10\x99+\x12\"\n\x1dk_EMsgClientLBSSetUGCResponse\x10\x9a+\x12\"\n\x1dk_EMsgClientAMGetClanOfficers\x10\x9b+\x12*\n%k_EMsgClientAMGetClanOfficersResponse\x10\x9c+\x12\"\n\x1dk_EMsgClientFriendProfileInfo\x10\x9f+\x12*\n%k_EMsgClientFriendProfileInfoResponse\x10\xa0+\x12#\n\x1ek_EMsgClientScreenshotsChanged\x10\xa7+\x12 \n\x1bk_EMsgClientLaunchClientApp\x10\xa8+\x12(\n#k_EMsgClientLaunchClientAppResponse\x10\xa9+\x12#\n\x1ek_EMsgClientRequestAccountData\x10\xad+\x12+\n&k_EMsgClientRequestAccountDataResponse\x10\xae+\x12(\n#k_EMsgClientResetForgottenPassword4\x10\xaf+\x12\x1b\n\x16k_EMsgClientHideFriend\x10\xb0+\x12\"\n\x1dk_EMsgClientFriendsGroupsList\x10\xb1+\x12&\n!k_EMsgClientGetClanActivityCounts\x10\xb2+\x12.\n)k_EMsgClientGetClanActivityCountsResponse\x10\xb3+\x12 \n\x1bk_EMsgClientOGSReportString\x10\xb4+\x12\x1d\n\x18k_EMsgClientOGSReportBug\x10\xb5+\x12\x19\n\x14k_EMsgClientSentLogs\x10\xb6+\x12 \n\x1bk_EMsgClientLogonGameServer\x10\xb7+\x12%\n k_EMsgAMClientCreateFriendsGroup\x10\xb8+\x12-\n(k_EMsgAMClientCreateFriendsGroupResponse\x10\xb9+\x12%\n k_EMsgAMClientDeleteFriendsGroup\x10\xba+\x12-\n(k_EMsgAMClientDeleteFriendsGroupResponse\x10\xbb+\x12%\n k_EMsgAMClientManageFriendsGroup\x10\xbc+\x12-\n(k_EMsgAMClientManageFriendsGroupResponse\x10\xbd+\x12#\n\x1ek_EMsgAMClientAddFriendToGroup\x10\xbe+\x12+\n&k_EMsgAMClientAddFriendToGroupResponse\x10\xbf+\x12(\n#k_EMsgAMClientRemoveFriendFromGroup\x10\xc0+\x12\x30\n+k_EMsgAMClientRemoveFriendFromGroupResponse\x10\xc1+\x12(\n#k_EMsgClientAMGetPersonaNameHistory\x10\xc2+\x12\x30\n+k_EMsgClientAMGetPersonaNameHistoryResponse\x10\xc3+\x12#\n\x1ek_EMsgClientRequestFreeLicense\x10\xc4+\x12+\n&k_EMsgClientRequestFreeLicenseResponse\x10\xc5+\x12\x30\n+k_EMsgClientDRMDownloadRequestWithCrashData\x10\xc6+\x12\x1c\n\x17k_EMsgClientAuthListAck\x10\xc7+\x12\"\n\x1dk_EMsgClientItemAnnouncements\x10\xc8+\x12)\n$k_EMsgClientRequestItemAnnouncements\x10\xc9+\x12&\n!k_EMsgClientFriendMsgEchoToSender\x10\xca+\x12%\n k_EMsgClientCommentNotifications\x10\xce+\x12,\n\'k_EMsgClientRequestCommentNotifications\x10\xcf+\x12&\n!k_EMsgClientPersonaChangeResponse\x10\xd0+\x12>\n9k_EMsgClientRequestWebAPIAuthenticateUserNonce_Deprecated\x10\xd1+\x12\x46\nAk_EMsgClientRequestWebAPIAuthenticateUserNonceResponse_Deprecated\x10\xd2+\x12#\n\x1ek_EMsgClientPlayerNicknameList\x10\xd3+\x12$\n\x1fk_EMsgAMClientSetPlayerNickname\x10\xd4+\x12,\n\'k_EMsgAMClientSetPlayerNicknameResponse\x10\xd5+\x12,\n\'k_EMsgClientGetNumberOfCurrentPlayersDP\x10\xd8+\x12\x34\n/k_EMsgClientGetNumberOfCurrentPlayersDPResponse\x10\xd9+\x12$\n\x1fk_EMsgClientServiceMethodLegacy\x10\xda+\x12,\n\'k_EMsgClientServiceMethodLegacyResponse\x10\xdb+\x12*\n%k_EMsgClientFriendUserStatusPublished\x10\xdc+\x12\x1e\n\x19k_EMsgClientCurrentUIMode\x10\xdd+\x12-\n(k_EMsgClientVanityURLChangedNotification\x10\xde+\x12\"\n\x1dk_EMsgClientUserNotifications\x10\xdf+\x12\x12\n\rk_EMsgBaseDFS\x10\xe0+\x12\x15\n\x10k_EMsgDFSGetFile\x10\xe1+\x12\x1e\n\x19k_EMsgDFSInstallLocalFile\x10\xe2+\x12\x18\n\x13k_EMsgDFSConnection\x10\xe3+\x12\x1d\n\x18k_EMsgDFSConnectionReply\x10\xe4+\x12\'\n\"k_EMsgClientDFSAuthenticateRequest\x10\xe5+\x12(\n#k_EMsgClientDFSAuthenticateResponse\x10\xe6+\x12\x1e\n\x19k_EMsgClientDFSEndSession\x10\xe7+\x12\x17\n\x12k_EMsgDFSPurgeFile\x10\xe8+\x12\x17\n\x12k_EMsgDFSRouteFile\x10\xe9+\x12\x1f\n\x1ak_EMsgDFSGetFileFromServer\x10\xea+\x12\x1e\n\x19k_EMsgDFSAcceptedResponse\x10\xeb+\x12\x1d\n\x18k_EMsgDFSRequestPingback\x10\xec+\x12\x1e\n\x19k_EMsgDFSRecvTransmitFile\x10\xed+\x12\x1e\n\x19k_EMsgDFSSendTransmitFile\x10\xee+\x12\x1e\n\x19k_EMsgDFSRequestPingback2\x10\xef+\x12\x1f\n\x1ak_EMsgDFSResponsePingback2\x10\xf0+\x12\"\n\x1dk_EMsgClientDFSDownloadStatus\x10\xf1+\x12\x1b\n\x16k_EMsgDFSStartTransfer\x10\xf2+\x12\x1e\n\x19k_EMsgDFSTransferComplete\x10\xf3+\x12\x1f\n\x1ak_EMsgDFSRouteFileResponse\x10\xf4+\x12&\n!k_EMsgClientNetworkingCertRequest\x10\xf5+\x12.\n)k_EMsgClientNetworkingCertRequestResponse\x10\xf6+\x12!\n\x1ck_EMsgClientChallengeRequest\x10\xf7+\x12\"\n\x1dk_EMsgClientChallengeResponse\x10\xf8+\x12#\n\x1ek_EMsgBadgeCraftedNotification\x10\xf9+\x12,\n\'k_EMsgClientNetworkingMobileCertRequest\x10\xfa+\x12\x34\n/k_EMsgClientNetworkingMobileCertRequestResponse\x10\xfb+\x12\x12\n\rk_EMsgBaseMDS\x10\xa8-\x12#\n\x1ek_EMsgMDSGetDepotDecryptionKey\x10\xb4-\x12+\n&k_EMsgMDSGetDepotDecryptionKeyResponse\x10\xb5-\x12(\n#k_EMsgMDSContentServerConfigRequest\x10\xc3-\x12!\n\x1ck_EMsgMDSContentServerConfig\x10\xc4-\x12\x1e\n\x19k_EMsgMDSGetDepotManifest\x10\xc5-\x12&\n!k_EMsgMDSGetDepotManifestResponse\x10\xc6-\x12#\n\x1ek_EMsgMDSGetDepotManifestChunk\x10\xc7-\x12\x1c\n\x17k_EMsgMDSToCSFlushChunk\x10\xd4-\x12\x1a\n\x15k_EMsgMDSMigrateChunk\x10\xd7-\x12\"\n\x1dk_EMsgMDSMigrateChunkResponse\x10\xd8-\x12\x1f\n\x1ak_EMsgMDSToCSFlushManifest\x10\xd9-\x12\x11\n\x0ck_EMsgCSBase\x10\xb8\x30\x12\x11\n\x0ck_EMsgCSPing\x10\xb9\x30\x12\x19\n\x14k_EMsgCSPingResponse\x10\xba\x30\x12\x12\n\rk_EMsgGMSBase\x10\x80\x32\x12!\n\x1ck_EMsgGMSGameServerReplicate\x10\x81\x32\x12\x1f\n\x1ak_EMsgClientGMSServerQuery\x10\x83\x32\x12\'\n\"k_EMsgGMSClientServerQueryResponse\x10\x84\x32\x12 \n\x1bk_EMsgAMGMSGameServerUpdate\x10\x85\x32\x12 \n\x1bk_EMsgAMGMSGameServerRemove\x10\x86\x32\x12\x1e\n\x19k_EMsgGameServerOutOfDate\x10\x87\x32\x12\x12\n\rk_EMsgMMSBase\x10\xc8\x33\x12\x1f\n\x1ak_EMsgClientMMSCreateLobby\x10\xc9\x33\x12\'\n\"k_EMsgClientMMSCreateLobbyResponse\x10\xca\x33\x12\x1d\n\x18k_EMsgClientMMSJoinLobby\x10\xcb\x33\x12%\n k_EMsgClientMMSJoinLobbyResponse\x10\xcc\x33\x12\x1e\n\x19k_EMsgClientMMSLeaveLobby\x10\xcd\x33\x12&\n!k_EMsgClientMMSLeaveLobbyResponse\x10\xce\x33\x12 \n\x1bk_EMsgClientMMSGetLobbyList\x10\xcf\x33\x12(\n#k_EMsgClientMMSGetLobbyListResponse\x10\xd0\x33\x12 \n\x1bk_EMsgClientMMSSetLobbyData\x10\xd1\x33\x12(\n#k_EMsgClientMMSSetLobbyDataResponse\x10\xd2\x33\x12 \n\x1bk_EMsgClientMMSGetLobbyData\x10\xd3\x33\x12\x1d\n\x18k_EMsgClientMMSLobbyData\x10\xd4\x33\x12$\n\x1fk_EMsgClientMMSSendLobbyChatMsg\x10\xd5\x33\x12 \n\x1bk_EMsgClientMMSLobbyChatMsg\x10\xd6\x33\x12!\n\x1ck_EMsgClientMMSSetLobbyOwner\x10\xd7\x33\x12)\n$k_EMsgClientMMSSetLobbyOwnerResponse\x10\xd8\x33\x12&\n!k_EMsgClientMMSSetLobbyGameServer\x10\xd9\x33\x12&\n!k_EMsgClientMMSLobbyGameServerSet\x10\xda\x33\x12#\n\x1ek_EMsgClientMMSUserJoinedLobby\x10\xdb\x33\x12!\n\x1ck_EMsgClientMMSUserLeftLobby\x10\xdc\x33\x12!\n\x1ck_EMsgClientMMSInviteToLobby\x10\xdd\x33\x12)\n$k_EMsgClientMMSFlushFrenemyListCache\x10\xde\x33\x12\x31\n,k_EMsgClientMMSFlushFrenemyListCacheResponse\x10\xdf\x33\x12\"\n\x1dk_EMsgClientMMSSetLobbyLinked\x10\xe0\x33\x12.\n)k_EMsgClientMMSSetRatelimitPolicyOnClient\x10\xe1\x33\x12\"\n\x1dk_EMsgClientMMSGetLobbyStatus\x10\xe2\x33\x12*\n%k_EMsgClientMMSGetLobbyStatusResponse\x10\xe3\x33\x12\x1a\n\x15k_EMsgMMSGetLobbyList\x10\xe4\x33\x12\"\n\x1dk_EMsgMMSGetLobbyListResponse\x10\xe5\x33\x12\x18\n\x13k_EMsgNonStdMsgBase\x10\x90\x35\x12\x1d\n\x18k_EMsgNonStdMsgMemcached\x10\x91\x35\x12\x1e\n\x19k_EMsgNonStdMsgHTTPServer\x10\x92\x35\x12\x1e\n\x19k_EMsgNonStdMsgHTTPClient\x10\x93\x35\x12\x1e\n\x19k_EMsgNonStdMsgWGResponse\x10\x94\x35\x12 \n\x1bk_EMsgNonStdMsgPHPSimulator\x10\x95\x35\x12\x19\n\x14k_EMsgNonStdMsgChase\x10\x96\x35\x12\x1f\n\x1ak_EMsgNonStdMsgDFSTransfer\x10\x97\x35\x12\x19\n\x14k_EMsgNonStdMsgTests\x10\x98\x35\x12\x1f\n\x1ak_EMsgNonStdMsgUMQpipeAAPL\x10\x99\x35\x12\x1a\n\x15k_EMSgNonStdMsgSyslog\x10\x9a\x35\x12\"\n\x1dk_EMsgNonStdMsgSteam2Emulator\x10\x9c\x35\x12\x1e\n\x19k_EMsgNonStdMsgRTMPServer\x10\x9d\x35\x12\x1d\n\x18k_EMsgNonStdMsgWebSocket\x10\x9e\x35\x12\x19\n\x14k_EMsgNonStdMsgRedis\x10\x9f\x35\x12\x12\n\rk_EMsgUDSBase\x10\xd8\x36\x12%\n k_EMsgClientUDSP2PSessionStarted\x10\xd9\x36\x12#\n\x1ek_EMsgClientUDSP2PSessionEnded\x10\xda\x36\x12\x1c\n\x17k_EMsgUDSRenderUserAuth\x10\xdb\x36\x12$\n\x1fk_EMsgUDSRenderUserAuthResponse\x10\xdc\x36\x12\x1d\n\x18k_EMsgClientInviteToGame\x10\xdd\x36\x12\x18\n\x13k_EMsgUDSHasSession\x10\xde\x36\x12 \n\x1bk_EMsgUDSHasSessionResponse\x10\xdf\x36\x12\x13\n\x0ek_EMsgMPASBase\x10\xbc\x37\x12\x1a\n\x15k_EMsgMPASVacBanReset\x10\xbd\x37\x12\x12\n\rk_EMsgKGSBase\x10\xa0\x38\x12\x12\n\rk_EMsgUCMBase\x10\x84\x39\x12!\n\x1ck_EMsgClientUCMAddScreenshot\x10\x85\x39\x12)\n$k_EMsgClientUCMAddScreenshotResponse\x10\x86\x39\x12#\n\x1ek_EMsgUCMResetCommunityContent\x10\x8b\x39\x12+\n&k_EMsgUCMResetCommunityContentResponse\x10\x8c\x39\x12$\n\x1fk_EMsgClientUCMDeleteScreenshot\x10\x8d\x39\x12,\n\'k_EMsgClientUCMDeleteScreenshotResponse\x10\x8e\x39\x12\x1f\n\x1ak_EMsgClientUCMPublishFile\x10\x8f\x39\x12\'\n\"k_EMsgClientUCMPublishFileResponse\x10\x90\x39\x12\'\n\"k_EMsgClientUCMDeletePublishedFile\x10\x93\x39\x12/\n*k_EMsgClientUCMDeletePublishedFileResponse\x10\x94\x39\x12\'\n\"k_EMsgClientUCMUpdatePublishedFile\x10\x9d\x39\x12/\n*k_EMsgClientUCMUpdatePublishedFileResponse\x10\x9e\x39\x12!\n\x1ck_EMsgUCMUpdatePublishedFile\x10\x9f\x39\x12)\n$k_EMsgUCMUpdatePublishedFileResponse\x10\xa0\x39\x12%\n k_EMsgUCMUpdatePublishedFileStat\x10\xa3\x39\x12!\n\x1ck_EMsgUCMReloadPublishedFile\x10\xa9\x39\x12&\n!k_EMsgUCMReloadUserFileListCaches\x10\xaa\x39\x12#\n\x1ek_EMsgUCMPublishedFileReported\x10\xab\x39\x12%\n k_EMsgUCMPublishedFilePreviewAdd\x10\xad\x39\x12-\n(k_EMsgUCMPublishedFilePreviewAddResponse\x10\xae\x39\x12(\n#k_EMsgUCMPublishedFilePreviewRemove\x10\xaf\x39\x12\x30\n+k_EMsgUCMPublishedFilePreviewRemoveResponse\x10\xb0\x39\x12%\n k_EMsgUCMPublishedFileSubscribed\x10\xb5\x39\x12\'\n\"k_EMsgUCMPublishedFileUnsubscribed\x10\xb6\x39\x12\x19\n\x14k_EMsgUCMPublishFile\x10\xb7\x39\x12!\n\x1ck_EMsgUCMPublishFileResponse\x10\xb8\x39\x12#\n\x1ek_EMsgUCMPublishedFileChildAdd\x10\xb9\x39\x12+\n&k_EMsgUCMPublishedFileChildAddResponse\x10\xba\x39\x12&\n!k_EMsgUCMPublishedFileChildRemove\x10\xbb\x39\x12.\n)k_EMsgUCMPublishedFileChildRemoveResponse\x10\xbc\x39\x12(\n#k_EMsgUCMPublishedFileParentChanged\x10\xbf\x39\x12.\n)k_EMsgClientUCMSetUserPublishedFileAction\x10\xc4\x39\x12\x36\n1k_EMsgClientUCMSetUserPublishedFileActionResponse\x10\xc5\x39\x12\x37\n2k_EMsgClientUCMEnumeratePublishedFilesByUserAction\x10\xc6\x39\x12?\n:k_EMsgClientUCMEnumeratePublishedFilesByUserActionResponse\x10\xc7\x39\x12$\n\x1fk_EMsgUCMGetUserSubscribedFiles\x10\xc9\x39\x12,\n\'k_EMsgUCMGetUserSubscribedFilesResponse\x10\xca\x39\x12#\n\x1ek_EMsgUCMFixStatsPublishedFile\x10\xcb\x39\x12;\n6k_EMsgClientUCMEnumerateUserSubscribedFilesWithUpdates\x10\xd2\x39\x12\x43\n>k_EMsgClientUCMEnumerateUserSubscribedFilesWithUpdatesResponse\x10\xd3\x39\x12)\n$k_EMsgUCMPublishedFileContentUpdated\x10\xd4\x39\x12(\n#k_EMsgClientUCMPublishedFileUpdated\x10\xd5\x39\x12\x11\n\x0ck_EMsgFSBase\x10\xcc:\x12#\n\x1ek_EMsgClientRichPresenceUpload\x10\xcd:\x12$\n\x1fk_EMsgClientRichPresenceRequest\x10\xce:\x12!\n\x1ck_EMsgClientRichPresenceInfo\x10\xcf:\x12 \n\x1bk_EMsgFSRichPresenceRequest\x10\xd0:\x12!\n\x1ck_EMsgFSRichPresenceResponse\x10\xd1:\x12\x1f\n\x1ak_EMsgFSComputeFrenematrix\x10\xd2:\x12\'\n\"k_EMsgFSComputeFrenematrixResponse\x10\xd3:\x12#\n\x1ek_EMsgFSPlayStatusNotification\x10\xd4:\x12 \n\x1bk_EMsgFSAddOrRemoveFollower\x10\xd6:\x12(\n#k_EMsgFSAddOrRemoveFollowerResponse\x10\xd7:\x12 \n\x1bk_EMsgFSUpdateFollowingList\x10\xd8:\x12 \n\x1bk_EMsgFSCommentNotification\x10\xd9:\x12&\n!k_EMsgFSCommentNotificationViewed\x10\xda:\x12#\n\x1ek_EMsgClientFSGetFollowerCount\x10\xdb:\x12+\n&k_EMsgClientFSGetFollowerCountResponse\x10\xdc:\x12!\n\x1ck_EMsgClientFSGetIsFollowing\x10\xdd:\x12)\n$k_EMsgClientFSGetIsFollowingResponse\x10\xde:\x12)\n$k_EMsgClientFSEnumerateFollowingList\x10\xdf:\x12\x31\n,k_EMsgClientFSEnumerateFollowingListResponse\x10\xe0:\x12(\n#k_EMsgFSGetPendingNotificationCount\x10\xe1:\x12\x30\n+k_EMsgFSGetPendingNotificationCountResponse\x10\xe2:\x12/\n*k_EMsgClientChatOfflineMessageNotification\x10\xe3:\x12/\n*k_EMsgClientChatRequestOfflineMessageCount\x10\xe4:\x12,\n\'k_EMsgClientChatGetFriendMessageHistory\x10\xe5:\x12\x34\n/k_EMsgClientChatGetFriendMessageHistoryResponse\x10\xe6:\x12>\n9k_EMsgClientChatGetFriendMessageHistoryForOfflineMessages\x10\xe7:\x12(\n#k_EMsgClientFSGetFriendsSteamLevels\x10\xe8:\x12\x30\n+k_EMsgClientFSGetFriendsSteamLevelsResponse\x10\xe9:\x12\x1e\n\x19k_EMsgAMRequestFriendData\x10\xea:\x12\x14\n\x0fk_EMsgDRMRange2\x10\xb0;\x12,\n\'k_EMsgCEGVersionSetEnableDisableRequest\x10\xb0;\x12-\n(k_EMsgCEGVersionSetEnableDisableResponse\x10\xb1;\x12#\n\x1ek_EMsgCEGPropStatusDRMSRequest\x10\xb2;\x12$\n\x1fk_EMsgCEGPropStatusDRMSResponse\x10\xb3;\x12\'\n\"k_EMsgCEGWhackFailureReportRequest\x10\xb4;\x12(\n#k_EMsgCEGWhackFailureReportResponse\x10\xb5;\x12\x1e\n\x19k_EMsgDRMSFetchVersionSet\x10\xb6;\x12&\n!k_EMsgDRMSFetchVersionSetResponse\x10\xb7;\x12\x13\n\x0ek_EMsgEconBase\x10\x94<\x12+\n&k_EMsgEconTrading_InitiateTradeRequest\x10\x95<\x12,\n\'k_EMsgEconTrading_InitiateTradeProposed\x10\x96<\x12,\n\'k_EMsgEconTrading_InitiateTradeResponse\x10\x97<\x12*\n%k_EMsgEconTrading_InitiateTradeResult\x10\x98<\x12#\n\x1ek_EMsgEconTrading_StartSession\x10\x99<\x12)\n$k_EMsgEconTrading_CancelTradeRequest\x10\x9a<\x12\"\n\x1dk_EMsgEconFlushInventoryCache\x10\x9b<\x12*\n%k_EMsgEconFlushInventoryCacheResponse\x10\x9c<\x12&\n!k_EMsgEconCDKeyProcessTransaction\x10\x9f<\x12.\n)k_EMsgEconCDKeyProcessTransactionResponse\x10\xa0<\x12\x1b\n\x16k_EMsgEconGetErrorLogs\x10\xa1<\x12#\n\x1ek_EMsgEconGetErrorLogsResponse\x10\xa2<\x12\x12\n\rk_EMsgRMRange\x10\xf8<\x12\x1c\n\x17k_EMsgRMTestVerisignOTP\x10\xf8<\x12$\n\x1fk_EMsgRMTestVerisignOTPResponse\x10\xf9<\x12 \n\x1bk_EMsgRMDeleteMemcachedKeys\x10\xfb<\x12\x19\n\x14k_EMsgRMRemoteInvoke\x10\xfc<\x12\x19\n\x14k_EMsgBadLoginIPList\x10\xfd<\x12\'\n\"k_EMsgRMMsgTraceAddOrUpdateTrigger\x10\xfe<\x12#\n\x1ek_EMsgRMMsgTraceRemoveTriggers\x10\xff<\x12\x1a\n\x15k_EMsgRMMsgTraceEvent\x10\x80=\x12\x12\n\rk_EMsgUGSBase\x10\xdc=\x12\x1f\n\x1ak_EMsgUGSUpdateGlobalStats\x10\xdc=\x12\"\n\x1dk_EMsgClientUGSGetGlobalStats\x10\xdd=\x12*\n%k_EMsgClientUGSGetGlobalStatsResponse\x10\xde=\x12\x14\n\x0fk_EMsgStoreBase\x10\xc0>\x12\x12\n\rk_EMsgUMQBase\x10\xa4?\x12\x17\n\x12k_EMsgWorkshopBase\x10\x88@\x12\x15\n\x10k_EMsgWebAPIBase\x10\xec@\x12$\n\x1fk_EMsgWebAPIValidateOAuth2Token\x10\xec@\x12,\n\'k_EMsgWebAPIValidateOAuth2TokenResponse\x10\xed@\x12%\n k_EMsgWebAPIRegisterGCInterfaces\x10\xef@\x12+\n&k_EMsgWebAPIInvalidateOAuthClientCache\x10\xf0@\x12*\n%k_EMsgWebAPIInvalidateOAuthTokenCache\x10\xf1@\x12\x1b\n\x16k_EMsgWebAPISetSecrets\x10\xf2@\x12\x17\n\x12k_EMsgBackpackBase\x10\xd0\x41\x12 \n\x1bk_EMsgBackpackAddToCurrency\x10\xd1\x41\x12(\n#k_EMsgBackpackAddToCurrencyResponse\x10\xd2\x41\x12\x12\n\rk_EMsgCREBase\x10\xb4\x42\x12\x1d\n\x18k_EMsgCREItemVoteSummary\x10\xb7\x42\x12%\n k_EMsgCREItemVoteSummaryResponse\x10\xb8\x42\x12)\n$k_EMsgCREUpdateUserPublishedItemVote\x10\xbb\x42\x12\x31\n,k_EMsgCREUpdateUserPublishedItemVoteResponse\x10\xbc\x42\x12-\n(k_EMsgCREGetUserPublishedItemVoteDetails\x10\xbd\x42\x12\x35\n0k_EMsgCREGetUserPublishedItemVoteDetailsResponse\x10\xbe\x42\x12\x16\n\x11k_EMsgSecretsBase\x10\x98\x43\x12\'\n\"k_EMsgSecretsRequestCredentialPair\x10\x98\x43\x12(\n#k_EMsgSecretsCredentialPairResponse\x10\x99\x43\x12\x19\n\x14k_EMsgBoxMonitorBase\x10\xfc\x43\x12\"\n\x1dk_EMsgBoxMonitorReportRequest\x10\xfc\x43\x12#\n\x1ek_EMsgBoxMonitorReportResponse\x10\xfd\x43\x12\x13\n\x0ek_EMsgPICSBase\x10\xc4\x45\x12(\n#k_EMsgClientPICSChangesSinceRequest\x10\xc5\x45\x12)\n$k_EMsgClientPICSChangesSinceResponse\x10\xc6\x45\x12\'\n\"k_EMsgClientPICSProductInfoRequest\x10\xc7\x45\x12(\n#k_EMsgClientPICSProductInfoResponse\x10\xc8\x45\x12\'\n\"k_EMsgClientPICSAccessTokenRequest\x10\xc9\x45\x12(\n#k_EMsgClientPICSAccessTokenResponse\x10\xca\x45\x12\'\n\"k_EMsgClientPICSPrivateBetaRequest\x10\xcb\x45\x12(\n#k_EMsgClientPICSPrivateBetaResponse\x10\xcc\x45\x12\x18\n\x13k_EMsgWorkerProcess\x10\xa8\x46\x12#\n\x1ek_EMsgWorkerProcessPingRequest\x10\xa8\x46\x12$\n\x1fk_EMsgWorkerProcessPingResponse\x10\xa9\x46\x12 \n\x1bk_EMsgWorkerProcessShutdown\x10\xaa\x46\x12\x1b\n\x16k_EMsgDRMWorkerProcess\x10\x8cG\x12%\n k_EMsgDRMWorkerProcessDRMAndSign\x10\x8cG\x12-\n(k_EMsgDRMWorkerProcessDRMAndSignResponse\x10\x8dG\x12\x30\n+k_EMsgDRMWorkerProcessSteamworksInfoRequest\x10\x8eG\x12\x31\n,k_EMsgDRMWorkerProcessSteamworksInfoResponse\x10\x8fG\x12/\n*k_EMsgDRMWorkerProcessInstallDRMDLLRequest\x10\x90G\x12\x30\n+k_EMsgDRMWorkerProcessInstallDRMDLLResponse\x10\x91G\x12\x30\n+k_EMsgDRMWorkerProcessSecretIdStringRequest\x10\x92G\x12\x31\n,k_EMsgDRMWorkerProcessSecretIdStringResponse\x10\x93G\x12\x37\n2k_EMsgDRMWorkerProcessInstallProcessedFilesRequest\x10\x96G\x12\x38\n3k_EMsgDRMWorkerProcessInstallProcessedFilesResponse\x10\x97G\x12-\n(k_EMsgDRMWorkerProcessExamineBlobRequest\x10\x98G\x12.\n)k_EMsgDRMWorkerProcessExamineBlobResponse\x10\x99G\x12\x30\n+k_EMsgDRMWorkerProcessDescribeSecretRequest\x10\x9aG\x12\x31\n,k_EMsgDRMWorkerProcessDescribeSecretResponse\x10\x9bG\x12\x32\n-k_EMsgDRMWorkerProcessBackfillOriginalRequest\x10\x9cG\x12\x33\n.k_EMsgDRMWorkerProcessBackfillOriginalResponse\x10\x9dG\x12\x30\n+k_EMsgDRMWorkerProcessValidateDRMDLLRequest\x10\x9eG\x12\x31\n,k_EMsgDRMWorkerProcessValidateDRMDLLResponse\x10\x9fG\x12.\n)k_EMsgDRMWorkerProcessValidateFileRequest\x10\xa0G\x12/\n*k_EMsgDRMWorkerProcessValidateFileResponse\x10\xa1G\x12\x31\n,k_EMsgDRMWorkerProcessSplitAndInstallRequest\x10\xa2G\x12\x32\n-k_EMsgDRMWorkerProcessSplitAndInstallResponse\x10\xa3G\x12)\n$k_EMsgDRMWorkerProcessGetBlobRequest\x10\xa4G\x12*\n%k_EMsgDRMWorkerProcessGetBlobResponse\x10\xa5G\x12/\n*k_EMsgDRMWorkerProcessEvaluateCrashRequest\x10\xa6G\x12\x30\n+k_EMsgDRMWorkerProcessEvaluateCrashResponse\x10\xa7G\x12-\n(k_EMsgDRMWorkerProcessAnalyzeFileRequest\x10\xa8G\x12.\n)k_EMsgDRMWorkerProcessAnalyzeFileResponse\x10\xa9G\x12,\n\'k_EMsgDRMWorkerProcessUnpackBlobRequest\x10\xaaG\x12-\n(k_EMsgDRMWorkerProcessUnpackBlobResponse\x10\xabG\x12,\n\'k_EMsgDRMWorkerProcessInstallAllRequest\x10\xacG\x12-\n(k_EMsgDRMWorkerProcessInstallAllResponse\x10\xadG\x12#\n\x1ek_EMsgDRMWorkerProcessSignFile\x10\xaeG\x12+\n&k_EMsgDRMWorkerProcessSignFileResponse\x10\xafG\x12\x1c\n\x17k_EMsgTestWorkerProcess\x10\xf0G\x12\x33\n.k_EMsgTestWorkerProcessLoadUnloadModuleRequest\x10\xf0G\x12\x34\n/k_EMsgTestWorkerProcessLoadUnloadModuleResponse\x10\xf1G\x12\x34\n/k_EMsgTestWorkerProcessServiceModuleCallRequest\x10\xf2G\x12\x35\n0k_EMsgTestWorkerProcessServiceModuleCallResponse\x10\xf3G\x12\x1a\n\x15k_EMsgQuestServerBase\x10\xd4H\x12 \n\x1bk_EMsgClientGetEmoticonList\x10\xf2H\x12\x1d\n\x18k_EMsgClientEmoticonList\x10\xf3H\x12\x12\n\rk_EMsgSLCBase\x10\xb8I\x12)\n$k_EMsgClientSharedLibraryStopPlaying\x10\xbeI\x12\x1b\n\x16k_EMsgRemoteClientBase\x10\x9cJ\x12$\n\x1fk_EMsgRemoteClientAuth_OBSOLETE\x10\x9cJ\x12,\n\'k_EMsgRemoteClientAuthResponse_OBSOLETE\x10\x9dJ\x12 \n\x1bk_EMsgRemoteClientAppStatus\x10\x9eJ\x12\"\n\x1dk_EMsgRemoteClientStartStream\x10\x9fJ\x12*\n%k_EMsgRemoteClientStartStreamResponse\x10\xa0J\x12\x1b\n\x16k_EMsgRemoteClientPing\x10\xa1J\x12#\n\x1ek_EMsgRemoteClientPingResponse\x10\xa2J\x12\x1b\n\x16k_EMsgClientUnlockH264\x10\xa3J\x12#\n\x1ek_EMsgClientUnlockH264Response\x10\xa4J\x12!\n\x1ck_EMsgRemoteClientAcceptEULA\x10\xa5J\x12*\n%k_EMsgRemoteClientGetControllerConfig\x10\xa6J\x12\x32\n-k_EMsgRemoteClientGetControllerConfigResponse\x10\xa7J\x12\'\n\"k_EMsgRemoteClientStreamingEnabled\x10\xa8J\x12$\n\x1fk_EMsgClientUnlockHEVC_OBSOLETE\x10\xa9J\x12,\n\'k_EMsgClientUnlockHEVCResponse_OBSOLETE\x10\xaaJ\x12$\n\x1fk_EMsgRemoteClientStatusRequest\x10\xabJ\x12%\n k_EMsgRemoteClientStatusResponse\x10\xacJ\x12+\n&k_EMsgRemoteClientAuthorizationRequest\x10\xadJ\x12,\n\'k_EMsgRemoteClientAuthorizationResponse\x10\xaeJ\x12\x31\n,k_EMsgRemoteClientAuthorizationCancelRequest\x10\xafJ\x12-\n(k_EMsgRemoteClientAuthorizationConfirmed\x10\xb0J\x12#\n\x1ek_EMsgRemoteClientProofRequest\x10\xb1J\x12$\n\x1fk_EMsgRemoteClientProofResponse\x10\xb2J\x12#\n\x1ek_EMsgRemoteClientWifiAPStatus\x10\xb3J\x12\'\n\"k_EMsgClientConcurrentSessionsBase\x10\x80K\x12$\n\x1fk_EMsgClientPlayingSessionState\x10\x80K\x12#\n\x1ek_EMsgClientKickPlayingSession\x10\x81K\x12\x1e\n\x19k_EMsgClientBroadcastBase\x10\xe4K\x12\x1e\n\x19k_EMsgClientBroadcastInit\x10\xe4K\x12 \n\x1bk_EMsgClientBroadcastFrames\x10\xe5K\x12$\n\x1fk_EMsgClientBroadcastDisconnect\x10\xe6K\x12&\n!k_EMsgClientBroadcastUploadConfig\x10\xe8K\x12\x16\n\x11k_EMsgBaseClient3\x10\xc8L\x12&\n!k_EMsgClientVoiceCallPreAuthorize\x10\xc8L\x12.\n)k_EMsgClientVoiceCallPreAuthorizeResponse\x10\xc9L\x12\'\n\"k_EMsgClientServerTimestampRequest\x10\xcaL\x12(\n#k_EMsgClientServerTimestampResponse\x10\xcbL\x12/\n*k_EMsgServiceMethodCallFromClientNonAuthed\x10\xccL\x12\x16\n\x11k_EMsgClientHello\x10\xcdL\x12)\n$k_EMsgClientEnableOrDisableDownloads\x10\xceL\x12\x31\n,k_EMsgClientEnableOrDisableDownloadsResponse\x10\xcfL\x12!\n\x1ck_EMsgClientFeatureGroupInfo\x10\xd0L\x12\x1b\n\x16k_EMsgClientLANP2PBase\x10\xacM\x12#\n\x1ek_EMsgClientLANP2PRequestChunk\x10\xacM\x12+\n&k_EMsgClientLANP2PRequestChunkResponse\x10\xadM\x12!\n\x1ck_EMsgClientPeerChunkRequest\x10\xaeM\x12\"\n\x1dk_EMsgClientPeerChunkResponse\x10\xafM\x12\x1a\n\x15k_EMsgClientLANP2PMax\x10\x8fN\x12\x1d\n\x18k_EMsgBaseWatchdogServer\x10\x90N\x12\x19\n\x14k_EMsgNotifyWatchdog\x10\x90N\x12 \n\x1bk_EMsgClientSiteLicenseBase\x10\xf4N\x12\x30\n+k_EMsgClientSiteLicenseSiteInfoNotification\x10\xf4N\x12$\n\x1fk_EMsgClientSiteLicenseCheckout\x10\xf5N\x12,\n\'k_EMsgClientSiteLicenseCheckoutResponse\x10\xf6N\x12-\n(k_EMsgClientSiteLicenseGetAvailableSeats\x10\xf7N\x12\x35\n0k_EMsgClientSiteLicenseGetAvailableSeatsResponse\x10\xf8N\x12/\n*k_EMsgClientSiteLicenseGetContentCacheInfo\x10\xf9N\x12\x37\n2k_EMsgClientSiteLicenseGetContentCacheInfoResponse\x10\xfaN\x12\x19\n\x14k_EMsgBaseChatServer\x10\xe0]\x12\x30\n+k_EMsgChatServerGetPendingNotificationCount\x10\xe0]\x12\x38\n3k_EMsgChatServerGetPendingNotificationCountResponse\x10\xe1]\x12\x1b\n\x16k_EMsgBaseSecretServer\x10\xc4^\x12\x1e\n\x19k_EMsgServerSecretChanged\x10\xc4^\x12\x11\n\x0ck_EMsgBaseWG\x10\xa8_\x12$\n\x1fk_EMsgWGConnectionProtocolError\x10\xa8_\x12(\n#k_EMsgWGConnectionValidateUserToken\x10\xa9_\x12\x30\n+k_EMsgWGConnectionValidateUserTokenResponse\x10\xaa_\x12&\n!k_EMsgWGConnectionLegacyWGRequest\x10\xab_\x12\'\n\"k_EMsgWGConnectionLegacyWGResponse\x10\xac_\x12\"\n\x1dk_EMsgClientPendingGameLaunch\x10\x8c`\x12*\n%k_EMsgClientPendingGameLaunchResponse\x10\x8d`\x1a\x02\x10\x01*\xcf\x04\n\x17\x45\x43lientPersonaStateFlag\x12#\n\x1fk_EClientPersonaStateFlagStatus\x10\x01\x12\'\n#k_EClientPersonaStateFlagPlayerName\x10\x02\x12&\n\"k_EClientPersonaStateFlagQueryPort\x10\x04\x12%\n!k_EClientPersonaStateFlagSourceID\x10\x08\x12%\n!k_EClientPersonaStateFlagPresence\x10\x10\x12%\n!k_EClientPersonaStateFlagLastSeen\x10@\x12*\n%k_EClientPersonaStateFlagUserClanRank\x10\x80\x01\x12\'\n\"k_EClientPersonaStateGameExtraInfo\x10\x80\x02\x12&\n!k_EClientPersonaStateGameDataBlob\x10\x80\x04\x12&\n!k_EClientPersonaStateFlagClanData\x10\x80\x08\x12&\n!k_EClientPersonaStateFlagFacebook\x10\x80\x10\x12*\n%k_EClientPersonaStateFlagRichPresence\x10\x80 \x12\'\n\"k_EClientPersonaStateFlagBroadcast\x10\x80@\x12\'\n!k_EClientPersonaStateFlagWatching\x10\x80\x80\x01*\xb9\x01\n\x14\x45MsgClanAccountFlags\x12\x1f\n\x1bk_EMsgClanAccountFlagPublic\x10\x01\x12\x1e\n\x1ak_EMsgClanAccountFlagLarge\x10\x02\x12\x1f\n\x1bk_EMsgClanAccountFlagLocked\x10\x04\x12!\n\x1dk_EMsgClanAccountFlagDisabled\x10\x08\x12\x1c\n\x18k_EMsgClanAccountFlagOGG\x10\x10*\x90\x03\n\x11\x45SteamReviewScore\x12.\n*k_ESteamReviewScore_OverwhelminglyPositive\x10\t\x12$\n k_ESteamReviewScore_VeryPositive\x10\x08\x12 \n\x1ck_ESteamReviewScore_Positive\x10\x07\x12&\n\"k_ESteamReviewScore_MostlyPositive\x10\x06\x12\x1d\n\x19k_ESteamReviewScore_Mixed\x10\x05\x12&\n\"k_ESteamReviewScore_MostlyNegative\x10\x04\x12 \n\x1ck_ESteamReviewScore_Negative\x10\x03\x12$\n k_ESteamReviewScore_VeryNegative\x10\x02\x12.\n*k_ESteamReviewScore_OverwhelminglyNegative\x10\x01\x12\x1c\n\x18k_ESteamReviewScore_None\x10\x00*\xbd\x01\n\x13\x45\x43odecUsagePlatform\x12 \n\x1ck_ECodecUsagePlatformUnknown\x10\x00\x12 \n\x1ck_ECodecUsagePlatformWindows\x10\x01\x12\x1e\n\x1ak_ECodecUsagePlatformMacOS\x10\x02\x12\x1e\n\x1ak_ECodecUsagePlatformLinux\x10\x03\x12\"\n\x1ek_ECodecUsagePlatformSteamDeck\x10\x04*\xc3\x01\n\x11\x45\x43odecUsageReason\x12\x1e\n\x1ak_ECodecUsageReasonUnknown\x10\x00\x12!\n\x1dk_ECodecUsageReasonRemotePlay\x10\x01\x12#\n\x1fk_ECodecUsageReasonBroadcasting\x10\x02\x12 \n\x1ck_ECodecUsageReasonGameVideo\x10\x03\x12$\n k_ECodecUsageReasonGameRecording\x10\x04\x42\x05H\x01\x90\x01\x00')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'enums_clientserver_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'H\001\220\001\000'
  _EMSG._options = None
  _EMSG._serialized_options = b'\020\001'
  _EMSG._serialized_start=30
  _EMSG._serialized_end=50965
  _ECLIENTPERSONASTATEFLAG._serialized_start=50968
  _ECLIENTPERSONASTATEFLAG._serialized_end=51559
  _EMSGCLANACCOUNTFLAGS._serialized_start=51562
  _EMSGCLANACCOUNTFLAGS._serialized_end=51747
  _ESTEAMREVIEWSCORE._serialized_start=51750
  _ESTEAMREVIEWSCORE._serialized_end=52150
  _ECODECUSAGEPLATFORM._serialized_start=52153
  _ECODECUSAGEPLATFORM._serialized_end=52342
  _ECODECUSAGEREASON._serialized_start=52345
  _ECODECUSAGEREASON._serialized_end=52540
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steamdatagram_messages_auth.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steamnetworkingsockets_messages_certs_pb2 as steamnetworkingsockets__messages__certs__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!steamdatagram_messages_auth.proto\x1a+steamnetworkingsockets_messages_certs.proto\"\xcf\x04\n CMsgSteamDatagramRelayAuthTicket\x12\x13\n\x0btime_expiry\x18\x01 \x01(\x07\x12)\n!authorized_client_identity_string\x18\x0e \x01(\t\x12\"\n\x1agameserver_identity_string\x18\x0f \x01(\t\x12\x1c\n\x14\x61uthorized_public_ip\x18\x03 \x01(\x07\x12\x1a\n\x12gameserver_address\x18\x0b \x01(\x0c\x12\x0e\n\x06\x61pp_id\x18\x07 \x01(\r\x12\x14\n\x0cvirtual_port\x18\n \x01(\r\x12\x42\n\x0c\x65xtra_fields\x18\x08 \x03(\x0b\x32,.CMsgSteamDatagramRelayAuthTicket.ExtraField\x12\"\n\x1alegacy_authorized_steam_id\x18\x02 \x01(\x06\x12\"\n\x1alegacy_gameserver_steam_id\x18\x04 \x01(\x06\x12 \n\x18legacy_gameserver_pop_id\x18\t \x01(\x07\x12\x30\n(legacy_authorized_client_identity_binary\x18\x0c \x01(\x0c\x12)\n!legacy_gameserver_identity_binary\x18\r \x01(\x0c\x1a\\\n\nExtraField\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x14\n\x0cstring_value\x18\x02 \x01(\t\x12\x13\n\x0bint64_value\x18\x03 \x01(\x12\x12\x15\n\rfixed64_value\x18\x05 \x01(\x06\"\xac\x01\n&CMsgSteamDatagramSignedRelayAuthTicket\x12\x1b\n\x13reserved_do_not_use\x18\x01 \x01(\x06\x12\x0e\n\x06ticket\x18\x03 \x01(\x0c\x12\x11\n\tsignature\x18\x04 \x01(\x0c\x12\x0e\n\x06key_id\x18\x02 \x01(\x06\x12\x32\n\x05\x63\x65rts\x18\x05 \x03(\x0b\x32#.CMsgSteamDatagramCertificateSigned\"d\n(CMsgSteamDatagramCachedCredentialsForApp\x12\x13\n\x0bprivate_key\x18\x01 \x01(\x0c\x12\x0c\n\x04\x63\x65rt\x18\x02 \x01(\x0c\x12\x15\n\rrelay_tickets\x18\x03 \x03(\x0c\"\xc7\x01\n+CMsgSteamDatagramGameCoordinatorServerLogin\x12\x16\n\x0etime_generated\x18\x01 \x01(\r\x12\r\n\x05\x61ppid\x18\x02 \x01(\r\x12\x0f\n\x07routing\x18\x03 \x01(\x0c\x12\x0f\n\x07\x61ppdata\x18\x04 \x01(\x0c\x12\x1e\n\x16legacy_identity_binary\x18\x05 \x01(\x0c\x12\x17\n\x0fidentity_string\x18\x06 \x01(\t\x12\x16\n\x0e\x64ummy_steam_id\x18\x63 \x01(\x06\"\x88\x01\n1CMsgSteamDatagramSignedGameCoordinatorServerLogin\x12\x31\n\x04\x63\x65rt\x18\x01 \x01(\x0b\x32#.CMsgSteamDatagramCertificateSigned\x12\r\n\x05login\x18\x02 \x01(\x0c\x12\x11\n\tsignature\x18\x03 \x01(\x0c\"\x8b\x01\n-CMsgSteamDatagramHostedServerAddressPlaintext\x12\x0c\n\x04ipv4\x18\x01 \x01(\x07\x12\x0c\n\x04ipv6\x18\x02 \x01(\x0c\x12\x0c\n\x04port\x18\x03 \x01(\r\x12\x16\n\x0erouting_secret\x18\x04 \x01(\x06\x12\x18\n\x10protocol_version\x18\x05 \x01(\rB\x05H\x01\x90\x01\x00')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'steamdatagram_messages_auth_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'H\001\220\001\000'
  _CMSGSTEAMDATAGRAMRELAYAUTHTICKET._serialized_start=83
  _CMSGSTEAMDATAGRAMRELAYAUTHTICKET._serialized_end=674
  _CMSGSTEAMDATAGRAMRELAYAUTHTICKET_EXTRAFIELD._serialized_start=582
  _CMSGSTEAMDATAGRAMRELAYAUTHTICKET_EXTRAFIELD._serialized_end=674
  _CMSGSTEAMDATAGRAMSIGNEDRELAYAUTHTICKET._serialized_start=677
  _CMSGSTEAMDATAGRAMSIGNEDRELAYAUTHTICKET._serialized_end=849
  _CMSGSTEAMDATAGRAMCACHEDCREDENTIALSFORAPP._serialized_start=851
  _CMSGSTEAMDATAGRAMCACHEDCREDENTIALSFORAPP._serialized_end=951
  _CMSGSTEAMDATAGRAMGAMECOORDINATORSERVERLOGIN._serialized_start=954
  _CMSGSTEAMDATAGRAMGAMECOORDINATORSERVERLOGIN._serialized_end=1153
  _CMSGSTEAMDATAGRAMSIGNEDGAMECOORDINATORSERVERLOGIN._serialized_start=1156
  _CMSGSTEAMDATAGRAMSIGNEDGAMECOORDINATORSERVERLOGIN._serialized_end=1292
  _CMSGSTEAMDATAGRAMHOSTEDSERVERADDRESSPLAINTEXT._serialized_start=1295
  _CMSGSTEAMDATAGRAMHOSTEDSERVERADDRESSPLAINTEXT._serialized_end=1434
# @@protoc_insertion_point(module_scope)
